import { CommonModule } from "@angular/common";
import { Component, ElementRef, Input, NgModule, Renderer2, ViewChild, ViewEncapsulation } from "@angular/core";
import { IgxIconModule } from "../icon/icon.component";
export var Size;
(function (Size) {
    Size[Size["SMALL"] = 0] = "SMALL";
    Size[Size["MEDIUM"] = 1] = "MEDIUM";
    Size[Size["LARGE"] = 2] = "LARGE";
})(Size || (Size = {}));
var IgxAvatar = (function () {
    function IgxAvatar(elementRef, renderer) {
        this.elementRef = elementRef;
        this.renderer = renderer;
        this.roundShape = "false";
        this.color = "white";
        this.sizeEnum = Size;
        this.fontName = "Titillium Web";
        this._icon = "android";
        this._addEventListeners(renderer);
    }
    Object.defineProperty(IgxAvatar.prototype, "size", {
        get: function () {
            return this._size === undefined ? "small" : this._size;
        },
        set: function (value) {
            var sizeType = this.sizeEnum[value.toUpperCase()];
            this._size = sizeType === undefined ? "small" : value.toLowerCase();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxAvatar.prototype, "bgColor", {
        get: function () {
            return this._bgColor;
        },
        set: function (value) {
            var color = value === "" ? "lightgrey" : value;
            this._bgColor = color;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxAvatar.prototype, "srcImage", {
        get: function () {
            return this.image ? this.image.nativeElement.src : "";
        },
        set: function (value) {
            this.image.nativeElement.src = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxAvatar.prototype, "isRounded", {
        get: function () {
            return this.roundShape.toUpperCase() === "TRUE" ? true : false;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxAvatar.prototype, "icon", {
        get: function () {
            return this._icon;
        },
        set: function (value) {
            this._icon = value;
        },
        enumerable: true,
        configurable: true
    });
    IgxAvatar.prototype.ngAfterViewInit = function () {
        if (this.initials && this.image) {
            var src = this.generateInitials(parseInt(this.image.nativeElement.width, 10));
            this.image.nativeElement.src = src;
        }
    };
    IgxAvatar.prototype.ngAfterContentChecked = function () {
        this.roleDescription = this.getRole();
    };
    IgxAvatar.prototype.getRole = function () {
        if (this.initials) {
            return "initials type avatar";
        }
        else if (this.src) {
            return "image type avatar";
        }
        else {
            return "icon type avatar";
        }
    };
    IgxAvatar.prototype.generateInitials = function (size) {
        var canvas = document.createElement("canvas");
        var fontSize = size / 2;
        var ctx;
        canvas.width = size;
        canvas.height = size;
        ctx = canvas.getContext("2d");
        ctx.fillStyle = this.bgColor;
        ctx.fillRect(0, 0, canvas.width, canvas.height);
        ctx.textAlign = "center";
        ctx.fillStyle = this.color;
        ctx.font = fontSize + ("px " + this.fontName);
        ctx.fillText(this.initials.toUpperCase(), size / 2, size - size / 2 + fontSize / 3);
        return canvas.toDataURL("image/png");
    };
    IgxAvatar.prototype._addEventListeners = function (renderer) { };
    IgxAvatar.decorators = [
        { type: Component, args: [{
                    encapsulation: ViewEncapsulation.None,
                    selector: "igx-avatar",
                    styles: ["\n      .igx-avatar,.igx-avatar--rounded,.igx-avatar--small,.igx-avatar--medium,.igx-avatar--large,.igx-avatar--icon,.igx-avatar--image{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;position:relative;pointer-events:none}.igx-avatar--rounded{border-radius:50%}.igx-avatar--small{width:2.5em;height:2.5em}.igx-avatar--medium{width:4em;height:4em}.igx-avatar--large{width:5.5em;height:5.5em}.igx-avatar--icon{background-color:rgba(0,0,0,0.26)}.igx-avatar--image{background-color:transparent !important}\n    "],
                    template: "\n      <div class=\"igx-avatar igx-avatar--{{size}}\" aria-label=\"avatar\" role=\"img\">\n          <img #image *ngIf=\"src || initials\" src=\"{{src}}\" class=\"igx-avatar--image igx-avatar--{{size}}\" [class.igx-avatar--rounded]=\"isRounded\"\n              [style.backgroundColor]=\"bgColor\" [attr.aria-roledescription]=\"roleDescription\" />\n          <span *ngIf=\"!src && !initials\" class=\"igx-avatar--{{size}} igx-avatar--icon\" [class.igx-avatar--rounded]=\"isRounded\" [style.backgroundColor]=\"bgColor\"\n              [style.color]=\"color\" [attr.aria-roledescription]=\"roleDescription\">\n              <igx-icon fontSet=\"material\" [name]=\"icon\"></igx-icon>\n          </span>\n          <ng-content></ng-content>\n      </div>\n    "
                },] },
    ];
    /** @nocollapse */
    IgxAvatar.ctorParameters = function () { return [
        { type: ElementRef, },
        { type: Renderer2, },
    ]; };
    IgxAvatar.propDecorators = {
        "image": [{ type: ViewChild, args: ["image",] },],
        "initials": [{ type: Input },],
        "src": [{ type: Input },],
        "roundShape": [{ type: Input, args: ["roundShape",] },],
        "color": [{ type: Input },],
        "size": [{ type: Input },],
        "bgColor": [{ type: Input },],
        "icon": [{ type: Input },],
    };
    return IgxAvatar;
}());
export { IgxAvatar };
var IgxAvatarModule = (function () {
    function IgxAvatarModule() {
    }
    IgxAvatarModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [IgxAvatar],
                    exports: [IgxAvatar],
                    imports: [CommonModule, IgxIconModule]
                },] },
    ];
    /** @nocollapse */
    IgxAvatarModule.ctorParameters = function () { return []; };
    return IgxAvatarModule;
}());
export { IgxAvatarModule };
//# sourceMappingURL=avatar.component.js.map