import { CommonModule } from "@angular/common";
import { Component, Input, NgModule, ViewEncapsulation } from "@angular/core";
import { IgxIconModule } from "../icon/icon.component";
export var Type;
(function (Type) {
    Type[Type["DEFAULT"] = 0] = "DEFAULT";
    Type[Type["INFO"] = 1] = "INFO";
    Type[Type["SUCCESS"] = 2] = "SUCCESS";
    Type[Type["WARNING"] = 3] = "WARNING";
    Type[Type["ERROR"] = 4] = "ERROR";
})(Type || (Type = {}));
export var Position;
(function (Position) {
    Position[Position["TOP_LEFT"] = 0] = "TOP_LEFT";
    Position[Position["TOP_RIGHT"] = 1] = "TOP_RIGHT";
    Position[Position["BOTTOM_LEFT"] = 2] = "BOTTOM_LEFT";
    Position[Position["BOTTOM_RIGHT"] = 3] = "BOTTOM_RIGHT";
})(Position || (Position = {}));
var IgxBadge = (function () {
    function IgxBadge() {
        this.typeEnum = Type;
        this.positionEnum = Position;
        this._type = "";
    }
    Object.defineProperty(IgxBadge.prototype, "type", {
        get: function () {
            return this._type === undefined ? "default" : this._type;
        },
        set: function (value) {
            var sizeType = this.typeEnum[value.toUpperCase()];
            this._type = sizeType === undefined ? "default" : value.toLowerCase();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxBadge.prototype, "position", {
        get: function () {
            return this._position === undefined ? "top-right" : this._position;
        },
        set: function (value) {
            var positionType = this.positionEnum[value.replace("-", "_").toUpperCase()];
            this._position = positionType === undefined ? "top-right" : value.toLowerCase();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxBadge.prototype, "value", {
        get: function () {
            return this._value === undefined ? "?" : this._value;
        },
        set: function (value) {
            this._value = value === undefined ? "-" : value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxBadge.prototype, "iconBdg", {
        get: function () {
            return this._iconBdg;
        },
        set: function (value) {
            this._iconBdg = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxBadge.prototype, "roleDescription", {
        get: function () {
            var message;
            // tslint:disable-next-line:prefer-conditional-expression
            if (this._iconBdg) {
                message = this._type + " type badge with icon type " + this._iconBdg;
            }
            else if (this._value) {
                message = this._type + " badge type with value " + this._value;
            }
            else {
                message = this._type + " badge type without value";
            }
            return message;
        },
        enumerable: true,
        configurable: true
    });
    IgxBadge.prototype.setClasses = function () {
        var classes = {};
        switch (this.typeEnum[this._type.toUpperCase()]) {
            case Type.DEFAULT:
                classes = {
                    "igx-badge__circle--default": true
                };
                break;
            case Type.INFO:
                classes = {
                    "igx-badge__circle--info": true
                };
                break;
            case Type.SUCCESS:
                classes = {
                    "igx-badge__circle--success": true
                };
                break;
            case Type.WARNING:
                classes = {
                    "igx-badge__circle--warning": true
                };
                break;
            case Type.ERROR:
                classes = {
                    "igx-badge__circle--error": true
                };
                break;
        }
        return classes;
    };
    IgxBadge.prototype.setPosition = function () {
        var className = {};
        switch (this.positionEnum[this.position.replace("-", "_").toUpperCase()]) {
            case Position.BOTTOM_LEFT:
                className = {
                    "igx-badge--bottom-left": true
                };
                break;
            case Position.BOTTOM_RIGHT:
                className = {
                    "igx-badge--bottom-right": true
                };
                break;
            case Position.TOP_LEFT:
                className = {
                    "igx-badge--top-left": true
                };
                break;
            case Position.TOP_RIGHT:
                className = {
                    "igx-badge--top-right": true
                };
                break;
        }
        return className;
    };
    IgxBadge.decorators = [
        { type: Component, args: [{
                    encapsulation: ViewEncapsulation.None,
                    selector: "igx-badge",
                    styles: ["\n      .igx-badge,.igx-badge--top-left,.igx-badge--bottom-left,.igx-badge--top-right,.igx-badge--bottom-right{position:absolute;max-width:100%}.igx-badge__circle{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;min-width:22px;height:22px;font-size:.625em;font-weight:600;color:#fff;background-color:#e41c77;border:0 solid #fff;line-height:2px;border-radius:4px;-webkit-box-shadow:0 1px 3px 0 rgba(0,0,0,0.26),0 1px 1px 0 rgba(0,0,0,0.12),0 2px 1px -1px rgba(0,0,0,0.08);box-shadow:0 1px 3px 0 rgba(0,0,0,0.26),0 1px 1px 0 rgba(0,0,0,0.12),0 2px 1px -1px rgba(0,0,0,0.08);overflow:hidden}.igx-badge__circle i{font-size:.6875em;font-weight:600}.igx-badge__circle-value{white-space:nowrap;padding:4px}.igx-badge__circle{border-radius:11px}.igx-badge__circle--success{background-color:#4caf50}.igx-badge__circle--info{background-color:#0375be}.igx-badge__circle--warning{background-color:#fbb13c}.igx-badge__circle--error{background-color:#f44336}.igx-badge--hidden{visibility:hidden}.igx-badge--top-left{top:-5px;left:-5px}.igx-badge--top-right{top:-5px;right:-5px}.igx-badge--bottom-left{bottom:-5px;left:-5px}.igx-badge--bottom-right{bottom:-5px;right:-5px}@-webkit-keyframes scale-in{0%{-webkit-transform:scale(0);transform:scale(0)}}@keyframes scale-in{0%{-webkit-transform:scale(0);transform:scale(0)}}\n    "],
                    template: "\n      <div [ngClass]=\"setPosition()\" aria-label=\"badge\" role=\"img\">\n      \t<div class=\"igx-badge__circle\" [ngClass]=\"setClasses()\" [attr.aria-roledescription]=\"roleDescription\">\n      \t\t<span *ngIf=\"!iconBdg\" class=\"igx-badge__circle-value\">{{value}}</span>\n      \t\t<igx-icon *ngIf=\"iconBdg\" fontSet=\"material\" [name]=\"iconBdg\"></igx-icon>\n      \t\t<!-- <i *ngIf=\"iconBdg\" class=\"material-icons igx-badge__circle-value\" >{{iconBdg}}</i> -->\n      \t</div>\n      </div>\n    "
                },] },
    ];
    /** @nocollapse */
    IgxBadge.ctorParameters = function () { return []; };
    IgxBadge.propDecorators = {
        "type": [{ type: Input },],
        "position": [{ type: Input },],
        "value": [{ type: Input },],
        "iconBdg": [{ type: Input, args: ["icon",] },],
    };
    return IgxBadge;
}());
export { IgxBadge };
var IgxBadgeModule = (function () {
    function IgxBadgeModule() {
    }
    IgxBadgeModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [IgxBadge],
                    exports: [IgxBadge],
                    imports: [CommonModule, IgxIconModule]
                },] },
    ];
    /** @nocollapse */
    IgxBadgeModule.ctorParameters = function () { return []; };
    return IgxBadgeModule;
}());
export { IgxBadgeModule };
//# sourceMappingURL=badge.component.js.map