import { CommonModule } from "@angular/common";
import { ChangeDetectorRef, Component, ElementRef, EventEmitter, Input, NgModule, Output, QueryList, Renderer2, ViewChildren } from "@angular/core";
import { IgxButton, IgxButtonModule } from "../button/button.directive";
import { IgxRippleModule } from "../directives/ripple.directive";
import { IgxIconModule } from "../icon/icon.component";
export var ButtonGroupAlignment;
(function (ButtonGroupAlignment) {
    ButtonGroupAlignment[ButtonGroupAlignment["horizontal"] = 0] = "horizontal";
    ButtonGroupAlignment[ButtonGroupAlignment["vertical"] = 1] = "vertical";
})(ButtonGroupAlignment || (ButtonGroupAlignment = {}));
// ====================== BUTTON GROUP ================================
// The `<igx-buttonGroup>` component is a  container for buttons
var IgxButtonGroup = (function () {
    function IgxButtonGroup(_el, _renderer, cdr) {
        this._el = _el;
        this._renderer = _renderer;
        this.multiSelection = false;
        this.disabled = false;
        this.selectedIndexes = [];
        this.onSelect = new EventEmitter();
        this.onUnselect = new EventEmitter();
    }
    Object.defineProperty(IgxButtonGroup.prototype, "itemContentCssClass", {
        get: function () {
            return this._itemContentCssClass;
        },
        set: function (value) {
            this._itemContentCssClass = value || this._itemContentCssClass;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxButtonGroup.prototype, "alignment", {
        get: function () {
            return this._isVertical ? ButtonGroupAlignment.vertical : ButtonGroupAlignment.horizontal;
        },
        set: function (value) {
            this._isVertical = value === ButtonGroupAlignment.vertical;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxButtonGroup.prototype, "isVertical", {
        get: function () {
            return this._isVertical;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxButtonGroup.prototype, "selectedButtons", {
        get: function () {
            var _this = this;
            return this.buttons.filter(function (b, i) {
                return _this.selectedIndexes.indexOf(i) !== -1;
            });
        },
        enumerable: true,
        configurable: true
    });
    IgxButtonGroup.prototype.selectButton = function (index) {
        var _this = this;
        if (this.buttons.toArray()[index]._el.nativeElement.getAttribute("data-togglable") === "false"
            || this.buttons.toArray()[index]._el.nativeElement.classList.contains("igx-button--disabled")) {
            return;
        }
        var buttonElement = this.buttons.toArray()[index]._el.nativeElement;
        this.selectedIndexes.push(index);
        buttonElement.setAttribute("data-selected", true);
        this.onSelect.emit({ button: this.buttons.toArray()[index], index: index });
        this.values[index].selected = true;
        // deselect other buttons if multiSelection is not enabled
        if (!this.multiSelection && this.selectedIndexes.length > 0) {
            this.buttons.forEach(function (b, i) {
                if (i !== index && _this.selectedIndexes.indexOf(i) !== -1) {
                    _this.deselectButton(i);
                }
            });
        }
    };
    IgxButtonGroup.prototype.deselectButton = function (index) {
        if (this.buttons.toArray()[index]._el.nativeElement.getAttribute("data-togglable") === "false"
            || this.buttons.toArray()[index]._el.nativeElement.classList.contains("igx-button--disabled")) {
            return;
        }
        var buttonElement = this.buttons.toArray()[index]._el.nativeElement;
        this.selectedIndexes.splice(this.selectedIndexes.indexOf(index), 1);
        buttonElement.setAttribute("data-selected", false);
        this.onUnselect.emit({ button: this.buttons.toArray()[index], index: index });
        this.values[index].selected = false;
    };
    IgxButtonGroup.prototype.ngAfterViewInit = function () {
        var _this = this;
        // initial selection
        setTimeout(function () {
            _this.buttons.forEach(function (button, index) {
                if (!button.disabled && button._el.nativeElement.getAttribute("data-selected") === "true") {
                    _this.selectButton(index);
                }
            });
        }, 0);
    };
    IgxButtonGroup.prototype._clickHandler = function (event, i) {
        if (this.selectedIndexes.indexOf(i) !== -1) {
            this.deselectButton(i);
        }
        else {
            this.selectButton(i);
        }
    };
    IgxButtonGroup.decorators = [
        { type: Component, args: [{
                    selector: "igx-buttongroup",
                    styles: ["\n      .igx-button-group,.igx-button-group--vertical{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-flow:row nowrap;flex-flow:row nowrap;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;border-radius:2px;-webkit-box-shadow:0 1px 5px 0 rgba(0,0,0,0.26),0 2px 2px 0 rgba(0,0,0,0.12),0 3px 1px -2px rgba(0,0,0,0.08);box-shadow:0 1px 5px 0 rgba(0,0,0,0.26),0 2px 2px 0 rgba(0,0,0,0.12),0 3px 1px -2px rgba(0,0,0,0.08);-webkit-transition:-webkit-box-shadow .2s ease;transition:-webkit-box-shadow .2s ease;transition:box-shadow .2s ease;transition:box-shadow .2s ease, -webkit-box-shadow .2s ease;overflow:hidden}.igx-button-group--vertical{-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-flow:column nowrap;flex-flow:column nowrap}.igx-button-group__item,.igx-button-group__item--selected,.igx-button-group--vertical .igx-button-group__item,.igx-button-group--vertical .igx-button-group__item--selected{-webkit-box-sizing:content-box;box-sizing:content-box;-webkit-box-flex:1;-ms-flex-positive:1;flex-grow:1;-ms-flex-preferred-size:0;flex-basis:0;border:initial;border-left:1px solid;border-right:1px solid;border-color:transparent;min-width:24px;min-height:24px;border-radius:0;color:rgba(0,0,0,0.38);font-weight:600;background:#fff}.igx-button-group__item:first-child,.igx-button-group__item--selected:first-child{border-left:0}.igx-button-group__item:last-child,.igx-button-group__item--selected:last-child{border-right:0}.igx-button-group__item:hover,.igx-button-group__item--selected:hover,.igx-button-group__item--selected{color:rgba(0,0,0,0.54) !important;background:rgba(0,0,0,0.26) !important;border-color:rgba(0,0,0,0.08)}.igx-button-group--vertical .igx-button-group__item{border-left:0;border-right:0;border-bottom:1px solid;border-top:1px solid;border-color:transparent}.igx-button-group--vertical .igx-button-group__item:first-child{border-top:0}.igx-button-group--vertical .igx-button-group__item:last-child{border-bottom:0}.igx-button-group--vertical .igx-button-group__item--selected{color:rgba(0,0,0,0.54) !important;background:rgba(0,0,0,0.26) !important;border-color:rgba(0,0,0,0.08)}.igx-button-group__item-content{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-flow:row nowrap;flex-flow:row nowrap;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;text-align:center}.igx-button-group__item-content * ~ *{margin-left:.625em}\n    "],
                    template: "\n      <div class=\"igx-button-group\" role=\"group\" [class.igx-button-group--vertical]=\"isVertical\">\n\n          <span class=\"igx-button-group__item\" *ngFor=\"let button of values; let i = 'index'\" type=\"button\" (click)=\"_clickHandler($event, i)\"\n              igxButton=\"flat\" [attr.data-selected]=\"button.selected\" [attr.data-togglable]=\"button.togglable\" [attr.aria-pressed]=\"button.selected\"\n              [disabled]=\"disabled || button.disabled\" [igxButtonColor]=\"button.color\" [igxButtonBackground]=\"button.bgcolor\" [igxLabel]=\"button.label\"\n              [igxRipple]=\"button.ripple\" [class.igx-button-group__item--selected]=\"button.selected\">\n              <div class=\"igx-button-group__item-content {{ itemContentCssClass }}\">\n                  <igx-icon *ngIf=\"button.icon\" fontSet=\"material\" [name]=\"button.icon\"></igx-icon>\n                  <span *ngIf=\"button.label\">{{button.label}}</span>\n      </div>\n      </span>\n\n      </div>\n    "
                },] },
    ];
    /** @nocollapse */
    IgxButtonGroup.ctorParameters = function () { return [
        { type: ElementRef, },
        { type: Renderer2, },
        { type: ChangeDetectorRef, },
    ]; };
    IgxButtonGroup.propDecorators = {
        "buttons": [{ type: ViewChildren, args: [IgxButton,] },],
        "itemContentCssClass": [{ type: Input },],
        "multiSelection": [{ type: Input },],
        "values": [{ type: Input },],
        "disabled": [{ type: Input },],
        "alignment": [{ type: Input },],
        "onSelect": [{ type: Output },],
        "onUnselect": [{ type: Output },],
    };
    return IgxButtonGroup;
}());
export { IgxButtonGroup };
var IgxButtonGroupModule = (function () {
    function IgxButtonGroupModule() {
    }
    IgxButtonGroupModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [IgxButtonGroup],
                    exports: [IgxButtonGroup],
                    imports: [IgxButtonModule, CommonModule, IgxRippleModule, IgxIconModule]
                },] },
    ];
    /** @nocollapse */
    IgxButtonGroupModule.ctorParameters = function () { return []; };
    return IgxButtonGroupModule;
}());
export { IgxButtonGroupModule };
//# sourceMappingURL=buttonGroup.component.js.map