import { ElementRef, EventEmitter, OnInit } from "@angular/core";
import { ControlValueAccessor } from "@angular/forms";
import { ICalendarDate, WEEKDAYS } from "./calendar";
export declare enum CalendarView {
    DEFAULT = 0,
    YEAR = 1,
    DECADE = 2,
}
/**
 *
 *
 * @export
 * @class IgxCalendarComponent
 * @implements {OnInit}
 * @implements {DoCheck}
 * @implements {ControlValueAccessor}
 */
export declare class IgxCalendarComponent implements OnInit, ControlValueAccessor {
    private elementRef;
    /**
     * Returns the day on which the week starts
     *
     * @readonly
     * @type {(WEEKDAYS | number)}
     * @memberof IgxCalendarComponent
     */
    weekStart: WEEKDAYS | number;
    locale: string;
    selection: string;
    viewDate: Date;
    onSelection: EventEmitter<Date | Date[]>;
    value: Date | Date[];
    formatOptions: {
        day: string;
        month: string;
        weekday: string;
        year: string;
    };
    readonly activeView: CalendarView;
    readonly monthAction: string;
    private calendarModel;
    private _viewDate;
    private headerDate;
    private _activeView;
    private selectedDates;
    private _selection;
    private _rangeStarted;
    private _monthAction;
    constructor(elementRef: ElementRef);
    registerOnChange(fn: (_: Date) => void): void;
    registerOnTouched(fn: () => void): void;
    writeValue(value: Date | Date[]): void;
    ngOnInit(): void;
    generateWeekHeader(): string[];
    readonly getCalendarMonth: ICalendarDate[][];
    onDateClick(event: MouseEvent): void;
    selectDate(date: Date | Date[]): void;
    handleKeyDown(event: any): void;
    protected selectSingle(newVal: Date): void;
    protected selectMulti(newVal: Date | Date[]): void;
    protected selectRange(newVal: Date | Date[]): void;
    protected prevMonth(): void;
    protected nextMonth(): void;
    protected handleScroll(event: any): void;
    protected handlePageUpDown(event: any): void;
    protected handleKeyboardNavigation(event: any): void;
    protected getMonthName(date: Date): string;
    protected getFormattedDate(): {
        weekday: string;
        monthday: string;
    };
    protected getHeaderYear(): string;
    protected isInactive(day: ICalendarDate): boolean;
    protected isWeekend(day: ICalendarDate): boolean;
    protected isCurrentMonth(value: Date): boolean;
    protected isCurrentYear(value: number): boolean;
    protected isSelected(day: ICalendarDate): boolean;
    protected isToday(day: ICalendarDate): boolean;
    readonly isDefaultView: boolean;
    readonly isYearView: boolean;
    readonly isDecadeView: boolean;
    protected activeViewYear(): void;
    protected activeViewDecade(): void;
    protected getDecade(): number[];
    protected getYear(): Date[];
    protected changeYear(event: any): void;
    protected changeMonth(event: any): void;
    protected dateTracker(index: any, item: any): string;
    protected rowTracker(index: any, item: any): string;
    protected monthTracker(index: any, item: any): number;
    private _onTouchedCallback;
    private _onChangeCallback;
}
export declare class IgxCalendarModule {
}
