import { transition, trigger, useAnimation } from "@angular/animations";
import { CommonModule } from "@angular/common";
import { Component, ElementRef, EventEmitter, Input, NgModule, Output, ViewChild, ViewEncapsulation } from "@angular/core";
import { fadeIn, fadeOut, slideInBottom } from "../animations/main";
import { IgxButtonModule } from "../button/button.directive";
import { IgxRippleModule } from "../directives/ripple.directive";
var IgxDialog = (function () {
    function IgxDialog() {
        this.title = "";
        this.message = "";
        this.leftButtonLabel = "";
        this.leftButtonType = "flat";
        this.leftButtonColor = "";
        this.leftButtonBackgroundColor = "";
        this.leftButtonRipple = "";
        this.rightButtonLabel = "";
        this.rightButtonType = "flat";
        this.rightButtonColor = "";
        this.rightButtonBackgroundColor = "";
        this.rightButtonRipple = "";
        this.closeOnOutsideSelect = false;
        this.onOpen = new EventEmitter();
        this.onClose = new EventEmitter();
        this.onLeftButtonSelect = new EventEmitter();
        this.onRightButtonSelect = new EventEmitter();
        this._isOpen = false;
        this._titleId = IgxDialog.NEXT_ID++ + "_title";
    }
    Object.defineProperty(IgxDialog.prototype, "state", {
        get: function () {
            return this._state;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxDialog.prototype, "isOpen", {
        get: function () {
            return this._isOpen;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxDialog.prototype, "role", {
        get: function () {
            if (this.leftButtonLabel !== "" && this.rightButtonLabel !== "") {
                return "dialog";
            }
            else if (this.leftButtonLabel !== "" ||
                this.rightButtonLabel !== "") {
                return "alertdialog";
            }
            else {
                return "alert";
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxDialog.prototype, "titleId", {
        get: function () {
            return this._titleId;
        },
        enumerable: true,
        configurable: true
    });
    IgxDialog.prototype.open = function () {
        if (this.isOpen) {
            return;
        }
        this.toggleState("open");
        this.onOpen.emit(this);
    };
    IgxDialog.prototype.close = function () {
        if (!this.isOpen) {
            return;
        }
        this.toggleState(null);
        this.onClose.emit(this);
    };
    IgxDialog.prototype.onDialogSelected = function (event) {
        if (this.isOpen &&
            this.closeOnOutsideSelect &&
            event.target.classList.contains(IgxDialog.DIALOG_CLASS)) {
            this.close();
        }
    };
    IgxDialog.prototype.onInternalLeftButtonSelect = function (event) {
        this.onLeftButtonSelect.emit({ dialog: this, event: event });
    };
    IgxDialog.prototype.onInternalRightButtonSelect = function (event) {
        this.onRightButtonSelect.emit({ dialog: this, event: event });
    };
    IgxDialog.prototype.toggleState = function (state) {
        this._state = state;
        this._isOpen = state === "open" ? true : false;
    };
    IgxDialog.NEXT_ID = 1;
    IgxDialog.DIALOG_CLASS = "igx-dialog";
    IgxDialog.decorators = [
        { type: Component, args: [{
                    animations: [
                        trigger("fadeInOut", [
                            transition("void => open", useAnimation(fadeIn)),
                            transition("open => void", useAnimation(fadeOut))
                        ]),
                        trigger("slideIn", [
                            transition("void => open", useAnimation(slideInBottom))
                        ])
                    ],
                    encapsulation: ViewEncapsulation.None,
                    selector: "igx-dialog",
                    styles: ["\n      .igx-dialog{display:-webkit-box;display:-ms-flexbox;display:flex;position:fixed;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;top:0;right:0;left:0;bottom:0;background:rgba(0,0,0,0.38);z-index:24}.igx-dialog--hidden{display:none}.igx-dialog__window{max-width:25em;min-width:17.5em;padding:.75em 1.5em;border-radius:2px;background:#fff;-webkit-box-shadow:0 11px 15px -7px rgba(0,0,0,0.26),0 24px 38px 3px rgba(0,0,0,0.12),0 9px 46px 8px rgba(0,0,0,0.08);box-shadow:0 11px 15px -7px rgba(0,0,0,0.26),0 24px 38px 3px rgba(0,0,0,0.12),0 9px 46px 8px rgba(0,0,0,0.08)}.igx-dialog__window-title{color:rgba(0,0,0,0.74);font-size:1.25em;line-height:1em;padding-top:.75em;padding-bottom:.625em;font-weight:600}.igx-dialog__window-content{color:rgba(0,0,0,0.54);font-size:1em;line-height:1.125em;padding-top:.625em;padding-bottom:.75em}.igx-dialog__window-actions{display:-webkit-box;display:-ms-flexbox;display:flex;margin:0 -1.5em -.75em -1.5em;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-flow:row nowrap;flex-flow:row nowrap;-webkit-box-pack:end;-ms-flex-pack:end;justify-content:flex-end;padding:.5em}.igx-dialog__window-actions button ~ button{margin-left:8px}\n    "],
                    template: "\n      <div #dialog tabindex=\"-1\" class=\"igx-dialog\" *ngIf=\"isOpen\" [@fadeInOut]=\"state\" (click)=\"onDialogSelected($event)\">\n          <div #dialogWindow class=\"igx-dialog__window\" [@slideIn]=\"state\" [attr.role]=\"role\" [attr.aria-labelledby]=\"titleId\">\n              <div [attr.id]=\"titleId\" class=\"igx-dialog__window-title\">\n                  {{ title }}\n              </div>\n              <div class=\"igx-dialog__window-content\">\n                  <div *ngIf=\"message\">{{ message }}</div>\n                  <ng-content *ngIf=\"!message\"></ng-content>\n              </div>\n              <div class=\"igx-dialog__window-actions\">\n                  <button *ngIf=\"leftButtonLabel\" igxButton=\"{{ leftButtonType }}\" igxButtonColor=\"{{ leftButtonColor }}\" igxButtonBackground=\"{{ leftButtonBackgroundColor }}\"\n                      igxRipple=\"{{ leftButtonRipple }}\" (click)=\"onInternalLeftButtonSelect($event)\">\n                      {{ leftButtonLabel }}\n                  </button>\n                  <button *ngIf=\"rightButtonLabel\" igxButton=\"{{ rightButtonType }}\" igxButtonColor=\"{{ rightButtonColor }}\" igxButtonBackground=\"{{ rightButtonBackgroundColor }}\"\n                      igxRipple=\"{{ rightButtonRipple }}\" (click)=\"onInternalRightButtonSelect($event)\">\n                      {{ rightButtonLabel }}\n                  </button>\n              </div>\n          </div>\n      </div>\n    "
                },] },
    ];
    /** @nocollapse */
    IgxDialog.ctorParameters = function () { return []; };
    IgxDialog.propDecorators = {
        "title": [{ type: Input },],
        "message": [{ type: Input },],
        "leftButtonLabel": [{ type: Input },],
        "leftButtonType": [{ type: Input },],
        "leftButtonColor": [{ type: Input },],
        "leftButtonBackgroundColor": [{ type: Input },],
        "leftButtonRipple": [{ type: Input },],
        "rightButtonLabel": [{ type: Input },],
        "rightButtonType": [{ type: Input },],
        "rightButtonColor": [{ type: Input },],
        "rightButtonBackgroundColor": [{ type: Input },],
        "rightButtonRipple": [{ type: Input },],
        "closeOnOutsideSelect": [{ type: Input },],
        "onOpen": [{ type: Output },],
        "onClose": [{ type: Output },],
        "onLeftButtonSelect": [{ type: Output },],
        "onRightButtonSelect": [{ type: Output },],
        "dialogEl": [{ type: ViewChild, args: ["dialog",] },],
        "isOpen": [{ type: Input },],
        "role": [{ type: Input },],
        "titleId": [{ type: Input },],
    };
    return IgxDialog;
}());
export { IgxDialog };
var IgxDialogModule = (function () {
    function IgxDialogModule() {
    }
    IgxDialogModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [IgxDialog],
                    exports: [IgxDialog],
                    imports: [CommonModule, IgxButtonModule, IgxRippleModule]
                },] },
    ];
    /** @nocollapse */
    IgxDialogModule.ctorParameters = function () { return []; };
    return IgxDialogModule;
}());
export { IgxDialogModule };
//# sourceMappingURL=dialog.component.js.map