import { Directive, ElementRef, EventEmitter, HostBinding, HostListener, Input, NgModule, Output, Renderer2 } from "@angular/core";
var IgxDraggableDirective = (function () {
    function IgxDraggableDirective(_elementRef, _renderer) {
        this._elementRef = _elementRef;
        this._renderer = _renderer;
        this.effectAllowed = "move";
    }
    IgxDraggableDirective.prototype.ngOnInit = function () {
        this.draggable = true;
    };
    IgxDraggableDirective.prototype.ngOnDestroy = function () {
        this.draggable = false;
    };
    IgxDraggableDirective.prototype.onDragStart = function (event) {
        if (this.dragClass) {
            this._renderer.addClass(this._elementRef.nativeElement, this.dragClass);
        }
        event.dataTransfer.effectAllowed = this.effectAllowed;
        event.dataTransfer.setData("data", JSON.stringify(this.data));
    };
    IgxDraggableDirective.prototype.onDragEnd = function (event) {
        event.preventDefault();
        if (this.dragClass) {
            this._renderer.removeClass(this._elementRef.nativeElement, this.dragClass);
        }
    };
    IgxDraggableDirective.decorators = [
        { type: Directive, args: [{
                    selector: "[igxDraggable]"
                },] },
    ];
    /** @nocollapse */
    IgxDraggableDirective.ctorParameters = function () { return [
        { type: ElementRef, },
        { type: Renderer2, },
    ]; };
    IgxDraggableDirective.propDecorators = {
        "data": [{ type: Input, args: ["igxDraggable",] },],
        "dragClass": [{ type: Input },],
        "effectAllowed": [{ type: Input },],
        "draggable": [{ type: HostBinding, args: ["draggable",] },],
        "onDragStart": [{ type: HostListener, args: ["dragstart", ["$event"],] },],
        "onDragEnd": [{ type: HostListener, args: ["dragend", ["$event"],] },],
    };
    return IgxDraggableDirective;
}());
export { IgxDraggableDirective };
var IgxDroppableDirective = (function () {
    function IgxDroppableDirective(_elementRef, _renderer) {
        this._elementRef = _elementRef;
        this._renderer = _renderer;
        this.dropEffect = "move";
        this.onDrop = new EventEmitter();
    }
    IgxDroppableDirective.prototype.onDragEnter = function (event) {
        if (this.dropClass) {
            this._renderer.addClass(this._elementRef.nativeElement, this.dropClass);
        }
    };
    IgxDroppableDirective.prototype.onDragLeave = function (event) {
        if (this.dropClass) {
            this._renderer.removeClass(this._elementRef.nativeElement, this.dropClass);
        }
    };
    IgxDroppableDirective.prototype.onDragOver = function (event) {
        if (event.preventDefault) {
            event.preventDefault();
        }
        event.dataTransfer.dropEffect = this.dropEffect;
        return false;
    };
    IgxDroppableDirective.prototype.onDragDrop = function (event) {
        if (event.stopPropagation) {
            event.stopPropagation();
        }
        if (this.dropClass) {
            this._renderer.removeClass(this._elementRef.nativeElement, this.dropClass);
        }
        var eventData = JSON.parse(event.dataTransfer.getData("data"));
        var args = {
            dragData: eventData,
            dropData: this.data,
            event: event
        };
        this.onDrop.emit(args);
    };
    IgxDroppableDirective.decorators = [
        { type: Directive, args: [{
                    selector: "[igxDroppable]"
                },] },
    ];
    /** @nocollapse */
    IgxDroppableDirective.ctorParameters = function () { return [
        { type: ElementRef, },
        { type: Renderer2, },
    ]; };
    IgxDroppableDirective.propDecorators = {
        "data": [{ type: Input, args: ["igxDroppable",] },],
        "dropClass": [{ type: Input },],
        "dropEffect": [{ type: Input },],
        "onDrop": [{ type: Output },],
        "onDragEnter": [{ type: HostListener, args: ["dragenter", ["$event"],] },],
        "onDragLeave": [{ type: HostListener, args: ["dragleave", ["$event"],] },],
        "onDragOver": [{ type: HostListener, args: ["dragover", ["$event"],] },],
        "onDragDrop": [{ type: HostListener, args: ["drop", ["$event"],] },],
    };
    return IgxDroppableDirective;
}());
export { IgxDroppableDirective };
var IgxDragDropModule = (function () {
    function IgxDragDropModule() {
    }
    IgxDragDropModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [IgxDraggableDirective, IgxDroppableDirective],
                    exports: [IgxDraggableDirective, IgxDroppableDirective]
                },] },
    ];
    /** @nocollapse */
    IgxDragDropModule.ctorParameters = function () { return []; };
    return IgxDragDropModule;
}());
export { IgxDragDropModule };
//# sourceMappingURL=dragdrop.directive.js.map