import { Component, Directive, EventEmitter, HostBinding, HostListener, Input, Output, TemplateRef, ViewContainerRef, ViewEncapsulation } from "@angular/core";
import { SortingDirection } from "../data-operations/sorting-expression.interface";
import { IgxColumnComponent } from "./column.component";
// directives
var IgxCellTemplateDirective = (function () {
    function IgxCellTemplateDirective(template) {
        this.template = template;
    }
    IgxCellTemplateDirective.decorators = [
        { type: Directive, args: [{
                    selector: "[igxCell]"
                },] },
    ];
    /** @nocollapse */
    IgxCellTemplateDirective.ctorParameters = function () { return [
        { type: TemplateRef, },
    ]; };
    return IgxCellTemplateDirective;
}());
export { IgxCellTemplateDirective };
var IgxCellHeaderTemplateDirective = (function () {
    function IgxCellHeaderTemplateDirective(template) {
        this.template = template;
    }
    IgxCellHeaderTemplateDirective.decorators = [
        { type: Directive, args: [{
                    selector: "[igxHeader]"
                },] },
    ];
    /** @nocollapse */
    IgxCellHeaderTemplateDirective.ctorParameters = function () { return [
        { type: TemplateRef, },
    ]; };
    return IgxCellHeaderTemplateDirective;
}());
export { IgxCellHeaderTemplateDirective };
var IgxCellFooterTemplateDirective = (function () {
    function IgxCellFooterTemplateDirective(template) {
        this.template = template;
    }
    IgxCellFooterTemplateDirective.decorators = [
        { type: Directive, args: [{
                    selector: "[igxFooter]"
                },] },
    ];
    /** @nocollapse */
    IgxCellFooterTemplateDirective.ctorParameters = function () { return [
        { type: TemplateRef, },
    ]; };
    return IgxCellFooterTemplateDirective;
}());
export { IgxCellFooterTemplateDirective };
var IgxColumnSortingDirective = (function () {
    function IgxColumnSortingDirective() {
        this.sortDirection = SortingDirection.None;
        this.onSort = new EventEmitter();
    }
    Object.defineProperty(IgxColumnSortingDirective.prototype, "off", {
        get: function () {
            return this.sortDirection === SortingDirection.None;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxColumnSortingDirective.prototype, "asc", {
        get: function () {
            return this.sortDirection === SortingDirection.Asc;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxColumnSortingDirective.prototype, "desc", {
        get: function () {
            return this.sortDirection === SortingDirection.Desc;
        },
        enumerable: true,
        configurable: true
    });
    IgxColumnSortingDirective.prototype.onClick = function (event) {
        if (this.column.sortable) {
            this.sortDirection = ++this.sortDirection > SortingDirection.Desc ? SortingDirection.None
                : this.sortDirection;
            this.onSort.emit({
                column: this.column,
                direction: this.sortDirection
            });
        }
    };
    IgxColumnSortingDirective.decorators = [
        { type: Directive, args: [{
                    selector: "[igxColumnSorting]"
                },] },
    ];
    /** @nocollapse */
    IgxColumnSortingDirective.ctorParameters = function () { return []; };
    IgxColumnSortingDirective.propDecorators = {
        "column": [{ type: Input, args: ["igxColumnSorting",] },],
        "sortDirection": [{ type: Input },],
        "onSort": [{ type: Output },],
        "off": [{ type: HostBinding, args: ["class.off",] },],
        "asc": [{ type: HostBinding, args: ["class.asc",] },],
        "desc": [{ type: HostBinding, args: ["class.desc",] },],
        "onClick": [{ type: HostListener, args: ["click", ["$event"],] },],
    };
    return IgxColumnSortingDirective;
}());
export { IgxColumnSortingDirective };
// components
var IgxCellBodyComponent = (function () {
    function IgxCellBodyComponent(viewContainer) {
        this.viewContainer = viewContainer;
    }
    IgxCellBodyComponent.prototype.ngOnInit = function () {
        this.view = this.viewContainer.createEmbeddedView(this.column.bodyTemplate, this);
    };
    IgxCellBodyComponent.prototype.ngOnDestroy = function () {
        this.view.destroy();
    };
    IgxCellBodyComponent.decorators = [
        { type: Component, args: [{
                    encapsulation: ViewEncapsulation.None,
                    selector: "igx-cell-body",
                    template: ""
                },] },
    ];
    /** @nocollapse */
    IgxCellBodyComponent.ctorParameters = function () { return [
        { type: ViewContainerRef, },
    ]; };
    IgxCellBodyComponent.propDecorators = {
        "column": [{ type: Input },],
        "item": [{ type: Input },],
        "rowIndex": [{ type: Input },],
        "row": [{ type: Input },],
    };
    return IgxCellBodyComponent;
}());
export { IgxCellBodyComponent };
var IgxCellHeaderComponent = (function () {
    function IgxCellHeaderComponent(viewContainer) {
        this.viewContainer = viewContainer;
    }
    IgxCellHeaderComponent.prototype.ngOnInit = function () {
        this.view = this.viewContainer.createEmbeddedView(this.column.headerTemplate, this);
    };
    IgxCellHeaderComponent.prototype.ngOnDestroy = function () {
        this.view.destroy();
    };
    IgxCellHeaderComponent.decorators = [
        { type: Component, args: [{
                    encapsulation: ViewEncapsulation.None,
                    selector: "igx-cell-header",
                    template: ""
                },] },
    ];
    /** @nocollapse */
    IgxCellHeaderComponent.ctorParameters = function () { return [
        { type: ViewContainerRef, },
    ]; };
    IgxCellHeaderComponent.propDecorators = {
        "column": [{ type: Input },],
        "colIndex": [{ type: Input },],
    };
    return IgxCellHeaderComponent;
}());
export { IgxCellHeaderComponent };
var IgxCellFooterComponent = (function () {
    function IgxCellFooterComponent(viewContainer) {
        this.viewContainer = viewContainer;
    }
    IgxCellFooterComponent.prototype.ngOnInit = function () {
        this.view = this.viewContainer.createEmbeddedView(this.column.footerTemplate, this);
    };
    IgxCellFooterComponent.prototype.ngOnDestroy = function () {
        this.view.destroy();
    };
    IgxCellFooterComponent.decorators = [
        { type: Component, args: [{
                    selector: "igx-cell-footer",
                    template: ""
                },] },
    ];
    /** @nocollapse */
    IgxCellFooterComponent.ctorParameters = function () { return [
        { type: ViewContainerRef, },
    ]; };
    IgxCellFooterComponent.propDecorators = {
        "column": [{ type: Input },],
        "colIndex": [{ type: Input },],
    };
    return IgxCellFooterComponent;
}());
export { IgxCellFooterComponent };
var IgxColumnFilteringComponent = (function () {
    function IgxColumnFilteringComponent() {
        this.hidden = true;
        this.onFilter = new EventEmitter();
    }
    IgxColumnFilteringComponent.prototype.show = function () {
        this.hidden = false;
    };
    IgxColumnFilteringComponent.prototype.hide = function () {
        this.hidden = true;
    };
    IgxColumnFilteringComponent.prototype.toggle = function () {
        this.hidden = !this.hidden;
    };
    IgxColumnFilteringComponent.prototype.filterData = function (event) {
        this.onFilter.emit({
            column: this.column,
            value: event.target.value
        });
    };
    IgxColumnFilteringComponent.decorators = [
        { type: Component, args: [{
                    encapsulation: ViewEncapsulation.None,
                    selector: "igx-col-filter",
                    styles: ["\n      .igx-filtering{position:static}.igx-filtering__toggle{z-index:10}.igx-filtering__toggle i{font-size:1em;line-height:1em;padding:.5em}.igx-filtering__toggle--active{background:#0375be !important;color:#fff}.igx-filtering__options{display:block;position:absolute;width:calc(100% - 32px);-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;right:16px;left:16px;background:#fff;-webkit-box-shadow:0 2px 4px -1px rgba(0,0,0,0.26),0 4px 5px 0 rgba(0,0,0,0.12),0 1px 10px 0 rgba(0,0,0,0.08);box-shadow:0 2px 4px -1px rgba(0,0,0,0.26),0 4px 5px 0 rgba(0,0,0,0.12),0 1px 10px 0 rgba(0,0,0,0.08);border-radius:2px;padding:.5em;z-index:10;margin-top:8px}.igx-filtering__options>input{font-weight:initial;font-size:initial}\n    "],
                    template: "\n      <div class=\"igx-filtering\" (click)=\"$event.stopPropagation()\">\n          <div class=\"igx-filtering__toggle\">\n              <span class=\"toggle-icon\" igxButton=\"icon\" (click)=\"toggle()\" [class.igx-filtering__toggle--active]=\"!hidden\">\n                  <igx-icon fontSet=\"material\" name=\"filter_list\"></igx-icon>\n              </span>\n          </div>\n\n          <span class=\"igx-filtering__options\" *ngIf=\"!hidden\">\n              <input igxInput type=\"text\"\n                  [value]=\"value\"\n                  (input)=\"filterData($event)\"\n                  (blur)=\"hidden = !hidden\"\n              />\n          </span>\n      </div>\n    "
                },] },
    ];
    /** @nocollapse */
    IgxColumnFilteringComponent.ctorParameters = function () { return []; };
    IgxColumnFilteringComponent.propDecorators = {
        "column": [{ type: Input },],
        "value": [{ type: Input },],
        "hidden": [{ type: Input },],
        "onFilter": [{ type: Output },],
    };
    return IgxColumnFilteringComponent;
}());
export { IgxColumnFilteringComponent };
//# sourceMappingURL=grid.common.js.map