import { AfterContentInit, ChangeDetectorRef, ComponentFactoryResolver, DoCheck, ElementRef, EventEmitter, IterableDiffers, OnDestroy, OnInit, QueryList, Renderer2, ViewContainerRef } from "@angular/core";
import { DataContainer } from "../data-operations/data-container";
import { IgxColumnComponent } from "./column.component";
import { IgxColumnFilteredEvent, IgxColumnSortedEvent } from "./grid.common";
import { IgxPaginatorComponent, IgxPaginatorEvent } from "./paginator.component";
import { IDataState } from "../data-operations/data-state.interface";
import { IFilteringExpression } from "../data-operations/filtering-expression.interface";
import { ISortingExpression, SortingDirection } from "../data-operations/sorting-expression.interface";
import { IgxDialog } from "../dialog/dialog.component";
import { IgxDropEvent } from "../directives/dragdrop.directive";
export interface IgxGridBindingBehavior {
    process: (dataContainer: DataContainer) => void;
}
export interface IgxGridColumnInitEvent {
    column: IgxColumnComponent;
}
export interface IgxGridDataProcessingEvent {
    state: IDataState;
}
export interface IgxGridRowSelectionEvent {
    row: IgxGridRow;
}
export interface IgxGridCellSelectionEvent {
    cell: IgxGridCell;
}
export interface IgxGridFilterEvent {
    column: IgxColumnComponent;
    expression: IFilteringExpression;
}
export interface IgxGridEditEvent {
    row: IgxGridRow;
}
export interface IgxGridSortEvent {
    column: IgxColumnComponent;
    direction: SortingDirection;
    expression: ISortingExpression;
}
export interface IgxGridRow {
    index: number;
    record: any;
    element: HTMLElement;
    cells: IgxGridCell[];
}
export interface IgxGridCell {
    rowIndex: number;
    columnField: string;
    dataItem: any;
    element: HTMLElement;
}
/**
 *
 *
 * @export
 * @class IgxGridComponent
 * @implements {OnInit}
 * @implements {AfterContentInit}
 * @implements {DoCheck}
 * @implements {OnDestroy}
 */
export declare class IgxGridComponent implements OnInit, AfterContentInit, DoCheck, OnDestroy {
    private _renderer;
    private _elementRef;
    private _detector;
    private _itDiff;
    private _resolver;
    private _viewRef;
    protected static nextId: number;
    data: any[];
    perPage: number;
    state: IDataState;
    paging: boolean;
    id: string;
    autoGenerate: boolean;
    editingModal: IgxDialog;
    paginator: IgxPaginatorComponent;
    onEditDone: EventEmitter<IgxGridEditEvent>;
    onFilterDone: EventEmitter<IgxGridFilterEvent>;
    onSortingDone: EventEmitter<IgxGridSortEvent>;
    onMovingDone: EventEmitter<IgxDropEvent>;
    onCellSelection: EventEmitter<IgxGridCellSelectionEvent>;
    onRowSelection: EventEmitter<IgxGridRowSelectionEvent>;
    onPagingDone: EventEmitter<IgxPaginatorEvent>;
    onColumnInit: EventEmitter<IgxGridColumnInitEvent>;
    onBeforeProcess: EventEmitter<IgxGridBindingBehavior>;
    dataContainer: DataContainer;
    columns: IgxColumnComponent[];
    protected cols: QueryList<IgxColumnComponent>;
    readonly columnsToRender: IgxColumnComponent[];
    readonly hasEditableColumns: boolean;
    readonly hasSorting: boolean;
    readonly hasFiltering: boolean;
    readonly editableColumns: IgxColumnComponent[];
    protected selectedRow: any;
    private _data;
    private filteringExpressions;
    private sortingExpressions;
    private colDiffer;
    private _differ;
    private _paging;
    private _lastRow;
    private shouldDataBind;
    constructor(_renderer: Renderer2, _elementRef: ElementRef, _detector: ChangeDetectorRef, _itDiff: IterableDiffers, _resolver: ComponentFactoryResolver, _viewRef: ViewContainerRef);
    ngOnInit(): void;
    /**
     * @hidden
     */
    ngAfterContentInit(): void;
    /**
     * @hidden
     */
    ngDoCheck(): void;
    /**
     * @hidden
     */
    ngOnDestroy(): void;
    getColumnByIndex(index: number): any;
    getColumnByField(field: string): any;
    formatBody(record: any, column: IgxColumnComponent): any;
    formatHeader(column: IgxColumnComponent): any;
    /**
     * Returns the cell at rowIndex/columnIndex.
     *
     * @param {number} rowIndex
     * @param {number} columnIndex
     * @returns
     *
     * @memberOf IgxGrid
     */
    getCell(rowIndex: number, columnField: string): IgxGridCell;
    /**
     * Returns
     *
     * @param {number} rowIndex
     * @returns
     *
     * @memberOf IgxGrid
     */
    getRow(rowIndex: number): IgxGridRow;
    /**
     * Focuses the grid cell at position row x column.
     * Fires the onCellSelection event.
     *
     * @param {(number | string)} rowIndex      : the index of the row
     * @param {(number | string)} columnIndex   : the index of the column
     *
     * @memberOf IgxGrid
     */
    focusCell(rowIndex: number | string, columnIndex: number | string): void;
    /**
     * Focuses the grid row at index `index`.
     * Fires the onRowSelection event.
     *
     * @param {(number | string)} index
     *
     * @memberOf IgxGrid
     */
    focusRow(index: number | string): void;
    filterData(searchTerm: string, column: IgxColumnComponent): void;
    addRow(rowData: object, at?: number): void;
    deleteRow(row: object | number | string): void;
    updateRow(index: number, rowData: object): void;
    updateCell(index: number, columnField: string, value: any): void;
    sortColumn(column: IgxColumnComponent, direction: SortingDirection): void;
    paginate(page: number): void;
    /**
     * @hidden
     */
    navigate(event: any): void;
    /**
     * @hidden
     */
    protected checkColumns(): void;
    /**
     * @hidden
     */
    protected onRowFocus(event: any, index: number): void;
    protected onRowBlur(event: any): void;
    protected onCellFocus(event: any, index: number, columnField: string): void;
    protected onCellBlur(event: any): void;
    protected editCell(index: number, item: any, row: object): void;
    protected processFilter(event: IgxColumnFilteredEvent): void;
    protected _setValue(field: string, event: any): void;
    protected getSortedExpression(column: IgxColumnComponent): number;
    protected cancelEdit(): void;
    protected saveData(): void;
    protected moveColumn(event: IgxDropEvent): void;
    protected processSort(event: IgxColumnSortedEvent): void;
    /**
     * @hidden
     */
    protected _paginate(event: IgxPaginatorEvent): void;
    private autogenerate();
}
export declare class IgxGridModule {
}
