import { CommonModule } from "@angular/common";
import { Component, ContentChildren, ElementRef, EventEmitter, forwardRef, HostBinding, Inject, Input, NgModule, Output, QueryList, Renderer2, ViewChild } from "@angular/core";
import { IgxButtonModule } from "../button/button.directive";
import { HammerGesturesManager } from "../core/touch";
import { IgxRippleModule } from "../directives/ripple.directive";
export var IgxListPanState;
(function (IgxListPanState) {
    IgxListPanState[IgxListPanState["NONE"] = 0] = "NONE";
    IgxListPanState[IgxListPanState["LEFT"] = 1] = "LEFT";
    IgxListPanState[IgxListPanState["RIGHT"] = 2] = "RIGHT";
})(IgxListPanState || (IgxListPanState = {}));
// ====================== LIST ================================
// The `<igx-list>` directive is a list container for items and headers
var IgxList = (function () {
    function IgxList(element) {
        this.element = element;
        this.allowLeftPanning = false;
        this.allowRightPanning = false;
        this.hasNoItemsTemplate = false;
        this.emptyListMessage = "No items";
        this.emptyListButtonText = "Add";
        this.emptyListButtonClick = new EventEmitter();
        this.onLeftPan = new EventEmitter();
        this.onRightPan = new EventEmitter();
        this.onPanStateChange = new EventEmitter();
        this._innerStyle = "igx-list";
    }
    Object.defineProperty(IgxList.prototype, "innerStyle", {
        get: function () {
            return this._innerStyle;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxList.prototype, "items", {
        get: function () {
            var items = [];
            if (this.children !== undefined) {
                for (var _i = 0, _a = this.children.toArray(); _i < _a.length; _i++) {
                    var child = _a[_i];
                    if (!child.isHeader) {
                        items.push(child);
                    }
                }
            }
            return items;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxList.prototype, "headers", {
        get: function () {
            var headers = [];
            if (this.children !== undefined) {
                for (var _i = 0, _a = this.children.toArray(); _i < _a.length; _i++) {
                    var child = _a[_i];
                    if (child.isHeader) {
                        headers.push(child);
                    }
                }
            }
            return headers;
        },
        enumerable: true,
        configurable: true
    });
    IgxList.prototype.onEmptyListButtonClicked = function (event) {
        this.emptyListButtonClick.emit({ list: this, event: event });
    };
    IgxList.decorators = [
        { type: Component, args: [{
                    host: {
                        role: "list"
                    },
                    selector: "igx-list",
                    styles: ["\n      .igx-list{background-color:#fff;height:100%;overflow:hidden}.igx-list__empty,.igx-list__empty--custom{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-flow:column nowrap;flex-flow:column nowrap;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;height:inherit}.image{width:auto;max-height:120px}.message{text-align:center;color:#333;padding:1em;z-index:1}igx-list-item{display:block;position:relative;list-style-type:none;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.igx-list__header{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;color:#e41c77;background-color:#fff;font-size:.8125em;font-weight:normal;height:3em;line-height:3em;padding:.5em 1em;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.igx-list__item{display:-webkit-box;display:-ms-flexbox;display:flex;position:relative;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-flow:column wrap;flex-flow:column wrap;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;padding:.5em 1em;min-height:3em;font-size:1em;color:rgba(0,0,0,0.74);background-color:#fff;z-index:2}.igx-list__item:active{background-color:rgba(0,0,0,0.04);z-index:3}\n    "],
                    template: "\n      <div class=\"{{innerStyle}}\">\n        <ng-content></ng-content>\n\n        <section *ngIf=\"children.length === 0 && !hasNoItemsTemplate\" class=\"igx-list__empty\">\n          <img class=\"image\" alt=\"{{ emptyListMessage }} image.\" src=\"{{ emptyListImage }}\" />\n\n          <article class=\"message\">\n            <p>{{ emptyListMessage }}</p>\n            <button igxButton=\"raised\" igxRipple=\"white\" (click)=\"onEmptyListButtonClicked($event)\">{{ emptyListButtonText }}</button>\n          </article>\n        </section>\n\n        <ng-content *ngIf=\"children.length === 0 && hasNoItemsTemplate\" select=\".igx-list__empty--custom\">\n        </ng-content>\n\n      </div>\n    "
                },] },
    ];
    /** @nocollapse */
    IgxList.ctorParameters = function () { return [
        { type: ElementRef, },
    ]; };
    IgxList.propDecorators = {
        "children": [{ type: ContentChildren, args: [forwardRef(function () { return IgxListItem; }),] },],
        "allowLeftPanning": [{ type: Input },],
        "allowRightPanning": [{ type: Input },],
        "hasNoItemsTemplate": [{ type: Input },],
        "emptyListImage": [{ type: Input },],
        "emptyListMessage": [{ type: Input },],
        "emptyListButtonText": [{ type: Input },],
        "emptyListButtonClick": [{ type: Output },],
        "onLeftPan": [{ type: Output },],
        "onRightPan": [{ type: Output },],
        "onPanStateChange": [{ type: Output },],
    };
    return IgxList;
}());
export { IgxList };
// ====================== ITEM ================================
// The `<igx-item>` directive is a container intended for row items in
// a `<igx-list>` container.
var IgxListItem = (function () {
    function IgxListItem(list, _renderer) {
        this.list = list;
        this._renderer = _renderer;
        this.hidden = false;
        this.isHeader = false;
        this._panState = IgxListPanState.NONE;
        this._FRACTION_OF_WIDTH_TO_TRIGGER_GRIP = 0.5;
        this._innerStyle = "";
        this._previousPanDeltaX = 0;
    }
    Object.defineProperty(IgxListItem.prototype, "innerStyle", {
        get: function () {
            return this._innerStyle;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxListItem.prototype, "panState", {
        get: function () {
            return this._panState;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxListItem.prototype, "index", {
        get: function () {
            return this.list.children.toArray().indexOf(this);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxListItem.prototype, "width", {
        get: function () {
            if (this.element && this.element.nativeElement) {
                return this.element.nativeElement.offsetWidth;
            }
            else {
                return 0;
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxListItem.prototype, "left", {
        get: function () {
            return this.element.nativeElement.offsetLeft;
        },
        set: function (value) {
            var val = value + "";
            if (val.indexOf("px") === -1) {
                val += "px";
            }
            this.element.nativeElement.style.left = val;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxListItem.prototype, "maxLeft", {
        get: function () {
            return -this.width;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxListItem.prototype, "maxRight", {
        get: function () {
            return this.width;
        },
        enumerable: true,
        configurable: true
    });
    IgxListItem.prototype.ngOnInit = function () {
        if (this.isHeader) {
            this._innerStyle = "igx-list__header";
            this.role = "separator";
        }
        else {
            this._innerStyle = "igx-list__item";
            this.role = "listitem";
            this._addEventListeners();
            this.element.nativeElement.style.touchAction = "pan-y";
        }
        this.element.nativeElement.setAttribute("aria-label", this.element.nativeElement.textContent.trim());
    };
    IgxListItem.prototype.ngOnDestroy = function () {
    };
    IgxListItem.prototype._addEventListeners = function () {
        var _this = this;
        // Do not attach pan events if there is no options - no need to pan the item
        if (this._renderer && this.options && (this.list.allowLeftPanning || this.list.allowRightPanning)) {
            this._renderer.listen(this.element.nativeElement, "panstart", function (event) { _this.panStart(event); });
            this._renderer.listen(this.element.nativeElement, "panmove", function (event) { _this.panMove(event); });
            this._renderer.listen(this.element.nativeElement, "panend", function (event) { _this.panEnd(event); });
        }
    };
    IgxListItem.prototype.panStart = function (ev) {
        this._previousPanDeltaX = 0;
    };
    IgxListItem.prototype.panMove = function (ev) {
        var isPanningToLeft = this.left + ev.deltaX < this.left;
        if (isPanningToLeft) {
            this.left += ev.deltaX - this._previousPanDeltaX;
            if (this.list.allowRightPanning && !this.list.allowLeftPanning && this.left < 0) {
                this.left = 0;
            }
            else if (this.left < this.maxLeft) {
                this.left = this.maxLeft;
            }
        }
        else if (!isPanningToLeft) {
            this.left += ev.deltaX - this._previousPanDeltaX;
            if (this.list.allowLeftPanning && !this.list.allowRightPanning && this.left > 0) {
                this.left = 0;
            }
            else if (this.left > this.maxRight) {
                this.left = this.maxRight;
            }
        }
        this._previousPanDeltaX = ev.deltaX;
    };
    IgxListItem.prototype.panEnd = function (ev) {
        var oldPanState = this._panState;
        this.performMagneticGrip();
        if (oldPanState !== this._panState) {
            this.list.onPanStateChange.emit({ oldState: oldPanState, newState: this._panState, item: this });
            if (this._panState === IgxListPanState.LEFT) {
                this.list.onLeftPan.emit(this);
            }
            else if (this._panState === IgxListPanState.RIGHT) {
                this.list.onRightPan.emit(this);
            }
        }
        this._previousPanDeltaX = 0;
    };
    IgxListItem.prototype.performMagneticGrip = function () {
        var widthTriggeringGrip = this.width * this._FRACTION_OF_WIDTH_TO_TRIGGER_GRIP;
        if (this.left > 0) {
            if (this.left > widthTriggeringGrip) {
                this.left = this.maxRight;
                this._panState = IgxListPanState.RIGHT;
            }
            else {
                this.left = 0;
                this._panState = IgxListPanState.NONE;
            }
        }
        else {
            if (-this.left > widthTriggeringGrip) {
                this.left = this.maxLeft;
                this._panState = IgxListPanState.LEFT;
            }
            else {
                this.left = 0;
                this._panState = IgxListPanState.NONE;
            }
        }
    };
    IgxListItem.decorators = [
        { type: Component, args: [{
                    providers: [HammerGesturesManager],
                    selector: "igx-list-item",
                    styles: ["\n      .igx-list{background-color:#fff;height:100%;overflow:hidden}.igx-list__empty,.igx-list__empty--custom{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-flow:column nowrap;flex-flow:column nowrap;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;height:inherit}.image{width:auto;max-height:120px}.message{text-align:center;color:#333;padding:1em;z-index:1}igx-list-item{display:block;position:relative;list-style-type:none;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.igx-list__header{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center;color:#e41c77;background-color:#fff;font-size:.8125em;font-weight:normal;height:3em;line-height:3em;padding:.5em 1em;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.igx-list__item{display:-webkit-box;display:-ms-flexbox;display:flex;position:relative;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-flow:column wrap;flex-flow:column wrap;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;padding:.5em 1em;min-height:3em;font-size:1em;color:rgba(0,0,0,0.74);background-color:#fff;z-index:2}.igx-list__item:active{background-color:rgba(0,0,0,0.04);z-index:3}\n    "],
                    template: "\n      <div #wrapper class=\"{{innerStyle}}\" [hidden]=\"hidden\">\n        <ng-content></ng-content>\n      </div>\n    "
                },] },
    ];
    /** @nocollapse */
    IgxListItem.ctorParameters = function () { return [
        { type: IgxList, decorators: [{ type: Inject, args: [forwardRef(function () { return IgxList; }),] },] },
        { type: Renderer2, },
    ]; };
    IgxListItem.propDecorators = {
        "element": [{ type: ViewChild, args: ["wrapper",] },],
        "role": [{ type: HostBinding, args: ["attr.role",] },],
        "isHeader": [{ type: Input },],
        "href": [{ type: Input },],
        "options": [{ type: Input },],
    };
    return IgxListItem;
}());
export { IgxListItem };
var IgxListModule = (function () {
    function IgxListModule() {
    }
    IgxListModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [IgxList, IgxListItem],
                    exports: [IgxList, IgxListItem],
                    imports: [CommonModule, IgxButtonModule, IgxRippleModule]
                },] },
    ];
    /** @nocollapse */
    IgxListModule.ctorParameters = function () { return []; };
    return IgxListModule;
}());
export { IgxListModule };
//# sourceMappingURL=list.component.js.map