import { CommonModule } from "@angular/common";
import { Component, EventEmitter, Input, NgModule, Output, ViewEncapsulation } from "@angular/core";
import { IgxButtonModule } from "../button/button.directive";
import { IgxIconModule } from "../icon/icon.component";
var IgxNavbar = (function () {
    function IgxNavbar() {
        /**
             * The IgxNavbar action button visual state state
             * @type {boolean}
             */
        this.isActionButtonVisible = false;
        /**
             * The event that will be thrown when the action is executed,
             * provides reference to the IgxNavbar component as argument
             * @type {EventEmitter}
             */
        this.onAction = new EventEmitter();
    }
    IgxNavbar.prototype.ngAfterContentChecked = function () {
        this._titleId = "igx-navbar-" + IgxNavbar.NEXT_ID++;
    };
    Object.defineProperty(IgxNavbar.prototype, "titleId", {
        get: function () {
            return this._titleId;
        },
        enumerable: true,
        configurable: true
    });
    IgxNavbar.prototype._triggerAction = function () {
        this.onAction.emit(this);
    };
    IgxNavbar.NEXT_ID = 1;
    IgxNavbar.decorators = [
        { type: Component, args: [{
                    encapsulation: ViewEncapsulation.None,
                    selector: "igx-navbar",
                    styles: ["\n      .igx-navbar{display:-webkit-box;display:-ms-flexbox;display:flex;position:relative;-webkit-box-orient:horizontal;-webkit-box-direction:normal;-ms-flex-flow:row nowrap;flex-flow:row nowrap;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;width:100%;height:56px;padding:0 1em;background:#0375be;color:#fff;-webkit-box-shadow:0 2px 4px -1px rgba(0,0,0,0.26),0 4px 5px 0 rgba(0,0,0,0.12),0 1px 10px 0 rgba(0,0,0,0.08);box-shadow:0 2px 4px -1px rgba(0,0,0,0.26),0 4px 5px 0 rgba(0,0,0,0.12),0 1px 10px 0 rgba(0,0,0,0.08);z-index:4}.igx-navbar__left,.igx-navbar__right{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.igx-navbar__left *+*,.igx-navbar__right *+*{margin-left:16px}.igx-navbar__title{margin:0;font-size:1.125em;line-height:1.125em}\n    "],
                    template: "\n      <nav class=\"igx-navbar\" role=\u201Dnavigation\u201D [attr.aria-labelledby]=\"titleId\">\n          <div class=\"igx-navbar__left\">\n              <span class=\"igx-navbar__left-btn\" *ngIf=\"!isActionButtonVisible\">\n                  <button igxButton=\"navbar\" (click)=\"_triggerAction()\">\n                      <igx-icon fontSet=\"material\" [name]=\"actionButtonIcon\"></igx-icon>\n                  </button>\n              </span>\n              <span>\n                  <h1 class=\"igx-navbar__title\" [attr.id]=\"titleId\">{{ title }}</h1>\n              </span>\n          </div>\n          <div class=\"igx-navbar__right\">\n              <ng-content></ng-content>\n          </div>\n      </nav>\n    "
                },] },
    ];
    /** @nocollapse */
    IgxNavbar.ctorParameters = function () { return []; };
    IgxNavbar.propDecorators = {
        "isActionButtonVisible": [{ type: Input },],
        "actionButtonIcon": [{ type: Input },],
        "title": [{ type: Input },],
        "onAction": [{ type: Output },],
        "titleId": [{ type: Input },],
    };
    return IgxNavbar;
}());
export { IgxNavbar };
var IgxNavbarModule = (function () {
    function IgxNavbarModule() {
    }
    IgxNavbarModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [IgxNavbar],
                    exports: [IgxNavbar],
                    imports: [IgxButtonModule, IgxIconModule, CommonModule]
                },] },
    ];
    /** @nocollapse */
    IgxNavbarModule.ctorParameters = function () { return []; };
    return IgxNavbarModule;
}());
export { IgxNavbarModule };
//# sourceMappingURL=navbar.component.js.map