var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { Component, ElementRef, EventEmitter, Inject, Input, NgModule, Optional, Output, Renderer } from "@angular/core";
import "rxjs/add/observable/fromEvent";
import "rxjs/add/observable/interval";
import "rxjs/add/operator/debounce";
import { Observable } from "rxjs/Observable";
import { BaseComponent } from "../core/base";
import { NavigationService } from "../core/navigation";
import { HammerGesturesManager } from "../core/touch";
/**
 * Navigation Drawer component supports collapsible side navigation container.
 * Usage:
 * ```
 * <igx-nav-drawer id="ID" (event output bindings) [input bindings]>
 *  <div class="ig-drawer-content">
 *   <!-- expanded template -->
 *  </div>
 * </igx-nav-drawer>
 * ```
 * Can also include an optional `<div class="ig-drawer-mini-content">`.
 * ID required to register with NavigationService allow directives to target the control.
 */
var NavigationDrawer = (function (_super) {
    __extends(NavigationDrawer, _super);
    function NavigationDrawer(elementRef, _state, 
        // private animate: AnimationBuilder, TODO
        renderer, _touchManager) {
        var _this = _super.call(this, renderer) || this;
        _this.elementRef = elementRef;
        _this._state = _state;
        _this.renderer = renderer;
        _this._touchManager = _touchManager;
        /**
             * Position of the Navigation Drawer. Can be "left"(default) or "right". Only has effect when not pinned.
             */
        _this.position = "left";
        /**
             * Enables the use of touch gestures to manipulate the drawer - such as swipe/pan from edge to open,
             * swipe toggle and pan drag.
             */
        _this.enableGestures = true;
        /** State of the drawer. */
        _this.isOpen = false;
        /** Pinned state of the drawer. Currently only support  */
        _this.pin = false;
        /**
             * Minimum device width required for automatic pin to be toggled.
             * Deafult is 1024, can be set to falsy value to ignore.
             */
        _this.pinThreshold = 1024;
        /** Pinned state change output for two-way binding  */
        _this.pinChange = new EventEmitter();
        /** Event fired as the Navigation Drawer is about to open. */
        _this.opening = new EventEmitter();
        /** Event fired when the Navigation Drawer has opened. */
        _this.opened = new EventEmitter();
        /** Event fired as the Navigation Drawer is about to close. */
        _this.closing = new EventEmitter();
        /** Event fired when the Navigation Drawer has closed. */
        _this.closed = new EventEmitter();
        _this._hasMimiTempl = false;
        _this._gesturesAttached = false;
        _this._widthCache = { width: null, miniWidth: null };
        _this.css = {
            drawer: "ig-nav-drawer",
            mini: "mini",
            miniProjection: ".ig-drawer-mini-content",
            overlay: "ig-nav-drawer-overlay",
            styleDummy: "style-dummy"
        };
        /** Pan animation properties */
        _this._panning = false;
        _this._maxEdgeZone = 50;
        _this.checkPinThreshold = function (evt) {
            var windowWidth;
            if (_this.pinThreshold) {
                windowWidth = _this.getWindowWidth();
                if (!_this.pin && windowWidth >= _this.pinThreshold) {
                    _this.pin = true;
                    _this.pinChange.emit(true);
                }
                else if (_this.pin && windowWidth < _this.pinThreshold) {
                    _this.pin = false;
                    _this.pinChange.emit(false);
                }
            }
        };
        _this.swipe = function (evt) {
            // TODO: Could also force input type: http://stackoverflow.com/a/27108052
            if (!_this.enableGestures || evt.pointerType !== "touch") {
                return;
            }
            // HammerJS swipe is horizontal-only by default, don't check deltaY
            var deltaX;
            var startPosition;
            if (_this.position === "right") {
                // when on the right use inverse of deltaX
                deltaX = -evt.deltaX;
                startPosition = _this.getWindowWidth() - (evt.center.x + evt.distance);
            }
            else {
                deltaX = evt.deltaX;
                startPosition = evt.center.x - evt.distance;
            }
            // only accept closing swipe (ignoring minEdgeZone) when the drawer is expanded:
            if ((_this.isOpen && deltaX < 0) ||
                // positive deltaX from the edge:
                (deltaX > 0 && startPosition < _this.maxEdgeZone)) {
                _this.toggle(true);
            }
        };
        _this.panstart = function (evt) {
            // TODO: test code
            if (!_this.enableGestures || _this.pin || evt.pointerType !== "touch") {
                return;
            }
            var startPosition = _this.position === "right" ? _this.getWindowWidth() - (evt.center.x + evt.distance)
                : evt.center.x - evt.distance;
            // cache width during animation, flag to allow further handling
            if (_this.isOpen || (startPosition < _this.maxEdgeZone)) {
                _this._panning = true;
                _this._panStartWidth = _this.getExpectedWidth(!_this.isOpen);
                _this._panLimit = _this.getExpectedWidth(_this.isOpen);
                _this.renderer.setElementClass(_this.overlay, "panning", true);
                _this.renderer.setElementClass(_this.drawer, "panning", true);
            }
        };
        _this.pan = function (evt) {
            // TODO: input.deltaX = prevDelta.x + (center.x - offset.x);
            // get actual delta (not total session one) from event?
            // pan WILL also fire after a full swipe, only resize on flag
            if (!_this._panning) {
                return;
            }
            var right = _this.position === "right";
            // when on the right use inverse of deltaX
            var deltaX = right ? -evt.deltaX : evt.deltaX;
            var visibleWidth;
            var newX;
            var percent;
            visibleWidth = _this._panStartWidth + deltaX;
            if (_this.isOpen && deltaX < 0) {
                // when visibleWidth hits limit - stop animating
                if (visibleWidth <= _this._panLimit) {
                    return;
                }
                if (_this.hasAnimateWidth) {
                    percent = (visibleWidth - _this._panLimit) / (_this._panStartWidth - _this._panLimit);
                    newX = visibleWidth;
                }
                else {
                    percent = visibleWidth / _this._panStartWidth;
                    newX = evt.deltaX;
                }
                _this.setXSize(newX, percent.toPrecision(2));
            }
            else if (!_this.isOpen && deltaX > 0) {
                // when visibleWidth hits limit - stop animating
                if (visibleWidth >= _this._panLimit) {
                    return;
                }
                if (_this.hasAnimateWidth) {
                    percent = (visibleWidth - _this._panStartWidth) / (_this._panLimit - _this._panStartWidth);
                    newX = visibleWidth;
                }
                else {
                    percent = visibleWidth / _this._panLimit;
                    newX = (_this._panLimit - visibleWidth) * (right ? 1 : -1);
                }
                _this.setXSize(newX, percent.toPrecision(2));
            }
        };
        _this.panEnd = function (evt) {
            if (_this._panning) {
                var deltaX = _this.position === "right" ? -evt.deltaX : evt.deltaX;
                var visibleWidth = _this._panStartWidth + deltaX;
                _this.resetPan();
                // check if pan brought the drawer to 50%
                if (_this.isOpen && visibleWidth <= _this._panStartWidth / 2) {
                    _this.close(true);
                }
                else if (!_this.isOpen && visibleWidth >= _this._panLimit / 2) {
                    _this.open(true);
                }
                _this._panStartWidth = null;
            }
        };
        _this.toggleOpenedEvent = function (evt) {
            _this.elementRef.nativeElement.removeEventListener("transitionend", _this.toggleOpenedEvent, false);
            _this._resolveOpen("opened");
            delete _this._resolveClose;
        };
        _this.toggleClosedEvent = function (evt) {
            _this.elementRef.nativeElement.removeEventListener("transitionend", _this.toggleClosedEvent, false);
            _this._resolveClose("closed");
            delete _this._resolveClose;
        };
        return _this;
    }
    Object.defineProperty(NavigationDrawer.prototype, "drawer", {
        get: function () {
            if (!this._drawer) {
                this._drawer = this.getChild("." + this.css.drawer);
            }
            return this._drawer;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NavigationDrawer.prototype, "overlay", {
        get: function () {
            if (!this._overlay) {
                this._overlay = this.getChild("." + this.css.overlay);
            }
            return this._overlay;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NavigationDrawer.prototype, "styleDummy", {
        get: function () {
            if (!this._styleDummy) {
                this._styleDummy = this.getChild("." + this.css.styleDummy);
            }
            return this._styleDummy;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NavigationDrawer.prototype, "hasAnimateWidth", {
        /**
         * Property to decide whether to change width or translate the drawer from pan gesture.
         */
        get: /**
             * Property to decide whether to change width or translate the drawer from pan gesture.
             */
        function () {
            return this.pin || this._hasMimiTempl;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NavigationDrawer.prototype, "maxEdgeZone", {
        /**
         * Used for touch gestures (swipe and pan).
         * Defaults to 50 (in px) and is extended to at least 110% of the mini template width if available.
         * @protected set method
         */
        get: /**
             * Used for touch gestures (swipe and pan).
             * Defaults to 50 (in px) and is extended to at least 110% of the mini template width if available.
             * @protected set method
             */
        function () {
            return this._maxEdgeZone;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NavigationDrawer.prototype, "expectedWidth", {
        /**
         * Get the Drawer width for specific state. Will attempt to evaluate requested state and cache.
         */
        get: /**
             * Get the Drawer width for specific state. Will attempt to evaluate requested state and cache.
             */
        function () {
            return this.getExpectedWidth(false);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NavigationDrawer.prototype, "expectedMiniWidth", {
        /**
         * Get the Drawer mini width for specific state. Will attempt to evaluate requested state and cache.
         */
        get: /**
             * Get the Drawer mini width for specific state. Will attempt to evaluate requested state and cache.
             */
        function () {
            return this.getExpectedWidth(true);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NavigationDrawer.prototype, "touchManager", {
        get: function () {
            return this._touchManager;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NavigationDrawer.prototype, "state", {
        /**
         * Exposes optional navigation service
         */
        get: /**
             * Exposes optional navigation service
             */
        function () {
            return this._state;
        },
        enumerable: true,
        configurable: true
    });
    NavigationDrawer.prototype.ngOnInit = function () {
        // DOM and @Input()-s initialized
        if (this._state) {
            this._state.add(this.id, this);
        }
    };
    NavigationDrawer.prototype.ngAfterContentInit = function () {
        // wait for template and ng-content to be ready
        this._hasMimiTempl = this.getChild(this.css.miniProjection) !== null;
        this.updateEdgeZone();
        this.checkPinThreshold();
        // need to set height without absolute positioning
        this.ensureDrawerHeight();
        this.ensureEvents();
        // TODO: apply platform-safe Ruler from http://plnkr.co/edit/81nWDyreYMzkunihfRgX?p=preview
        // (https://github.com/angular/angular/issues/6515), blocked by https://github.com/angular/angular/issues/6904
    };
    NavigationDrawer.prototype.ngOnDestroy = function () {
        this._touchManager.destroy();
        if (this._state) {
            this._state.remove(this.id);
        }
        this._resizeObserver.unsubscribe();
    };
    NavigationDrawer.prototype.ngOnChanges = function (changes) {
        // simple settings can come from attribute set (rather than binding), make sure boolean props are converted
        if (changes.enableGestures && changes.enableGestures.currentValue !== undefined) {
            this.enableGestures = !!(this.enableGestures && this.enableGestures.toString() === "true");
            this.ensureEvents();
        }
        if (changes.pin && changes.pin.currentValue !== undefined) {
            this.pin = !!(this.pin && this.pin.toString() === "true");
            this.ensureDrawerHeight();
            if (this.pin) {
                this._touchManager.destroy();
                this._gesturesAttached = false;
            }
            else {
                this.ensureEvents();
            }
        }
        if (changes.pinThreshold) {
            if (this.pinThreshold) {
                this.ensureEvents();
                this.checkPinThreshold();
            }
            else {
                this._resizeObserver.unsubscribe();
                this._resizeObserver = null;
            }
        }
        if (changes.width && this.isOpen) {
            this.setDrawerWidth(changes.width.currentValue);
        }
        if (changes.miniWidth) {
            if (!this.isOpen) {
                this.setDrawerWidth(changes.miniWidth.currentValue);
            }
            this.updateEdgeZone();
        }
    };
    /**
     * Toggle the open state of the Navigation Drawer.
     * @param fireEvents Optional flag determining whether events should be fired or not.
     * @return Promise that is resolved once the operation completes.
     */
    /**
         * Toggle the open state of the Navigation Drawer.
         * @param fireEvents Optional flag determining whether events should be fired or not.
         * @return Promise that is resolved once the operation completes.
         */
    NavigationDrawer.prototype.toggle = /**
         * Toggle the open state of the Navigation Drawer.
         * @param fireEvents Optional flag determining whether events should be fired or not.
         * @return Promise that is resolved once the operation completes.
         */
    function (fireEvents) {
        if (this.isOpen) {
            return this.close(fireEvents);
        }
        else {
            return this.open(fireEvents);
        }
    };
    /**
     * Open the Navigation Drawer. Has no effect if already opened.
     * @param fireEvents Optional flag determining whether events should be fired or not.
     * @return Promise that is resolved once the operation completes.
     */
    /**
         * Open the Navigation Drawer. Has no effect if already opened.
         * @param fireEvents Optional flag determining whether events should be fired or not.
         * @return Promise that is resolved once the operation completes.
         */
    NavigationDrawer.prototype.open = /**
         * Open the Navigation Drawer. Has no effect if already opened.
         * @param fireEvents Optional flag determining whether events should be fired or not.
         * @return Promise that is resolved once the operation completes.
         */
    function (fireEvents) {
        var _this = this;
        if (this._panning) {
            this.resetPan();
        }
        if (this.isOpen) {
            return Promise.resolve();
        }
        if (fireEvents) {
            this.opening.emit("opening");
        }
        this.isOpen = true;
        // TODO: Switch to animate API when available
        // var animationCss = this.animate.css();
        //     animationCss
        //         .setStyles({'width':'50px'}, {'width':'400px'})
        //         .start(this.elementRef.nativeElement)
        //         .onComplete(() => animationCss.setToStyles({'width':'auto'}).start(this.elementRef.nativeElement));
        this.elementRef.nativeElement.addEventListener("transitionend", this.toggleOpenedEvent, false);
        this.setDrawerWidth(this.width);
        return new Promise(function (resolve) {
            _this._resolveOpen = function (value) {
                resolve(value);
                if (fireEvents) {
                    _this.opened.emit("opened");
                }
            };
        });
    };
    /**
     * Close the Navigation Drawer. Has no effect if already closed.
     * @param fireEvents Optional flag determining whether events should be fired or not.
     * @return Promise that is resolved once the operation completes.
     */
    /**
         * Close the Navigation Drawer. Has no effect if already closed.
         * @param fireEvents Optional flag determining whether events should be fired or not.
         * @return Promise that is resolved once the operation completes.
         */
    NavigationDrawer.prototype.close = /**
         * Close the Navigation Drawer. Has no effect if already closed.
         * @param fireEvents Optional flag determining whether events should be fired or not.
         * @return Promise that is resolved once the operation completes.
         */
    function (fireEvents) {
        var _this = this;
        if (this._panning) {
            this.resetPan();
        }
        if (!this.isOpen) {
            return Promise.resolve();
        }
        if (fireEvents) {
            this.closing.emit("closing");
        }
        this.isOpen = false;
        this.setDrawerWidth(this._hasMimiTempl ? this.miniWidth : "");
        this.elementRef.nativeElement.addEventListener("transitionend", this.toggleClosedEvent, false);
        return new Promise(function (resolve) {
            _this._resolveClose = function (value) {
                resolve(value);
                if (fireEvents) {
                    _this.closed.emit("closed");
                }
            };
        });
    };
    NavigationDrawer.prototype.set_maxEdgeZone = function (value) {
        this._maxEdgeZone = value;
    };
    NavigationDrawer.prototype.ensureDrawerHeight = function () {
        if (this.pin) {
            // TODO: nested in content?
            // setElementStyle warning https://github.com/angular/angular/issues/6563
            this.renderer.setElementStyle(this.drawer, "height", window.innerHeight + "px");
        }
    };
    /**
     * Get the Drawer width for specific state. Will attempt to evaluate requested state and cache.
     * @param mini Request mini width instead
     */
    /**
         * Get the Drawer width for specific state. Will attempt to evaluate requested state and cache.
         * @param mini Request mini width instead
         */
    NavigationDrawer.prototype.getExpectedWidth = /**
         * Get the Drawer width for specific state. Will attempt to evaluate requested state and cache.
         * @param mini Request mini width instead
         */
    function (mini) {
        if (mini) {
            if (!this._hasMimiTempl) {
                return 0;
            }
            if (this.miniWidth) {
                return parseFloat(this.miniWidth);
            }
            else {
                // if (!this.isOpen) { // This WON'T work due to transition timings...
                //     return this.elementRef.nativeElement.children[1].offsetWidth;
                // } else {
                if (this._widthCache.miniWidth === null) {
                    // force class for width calc. TODO?
                    this.renderer.setElementClass(this.styleDummy, this.css.drawer, true);
                    this.renderer.setElementClass(this.styleDummy, this.css.mini, true);
                    this._widthCache.miniWidth = this.styleDummy.offsetWidth;
                    this.renderer.setElementClass(this.styleDummy, this.css.drawer, false);
                    this.renderer.setElementClass(this.styleDummy, this.css.mini, false);
                }
                return this._widthCache.miniWidth;
            }
        }
        else {
            if (this.width) {
                return parseFloat(this.width);
            }
            else {
                if (this._widthCache.width === null) {
                    // force class for width calc. TODO?
                    this.renderer.setElementClass(this.styleDummy, this.css.drawer, true);
                    this._widthCache.width = this.styleDummy.offsetWidth;
                    this.renderer.setElementClass(this.styleDummy, this.css.drawer, false);
                }
                return this._widthCache.width;
            }
        }
    };
    NavigationDrawer.prototype.getWindowWidth = function () {
        return (window.innerWidth > 0) ? window.innerWidth : screen.width;
    };
    /**
     * Sets the drawer width.
     * @param width Width to set, must be valid CSS size string.
     */
    /**
         * Sets the drawer width.
         * @param width Width to set, must be valid CSS size string.
         */
    NavigationDrawer.prototype.setDrawerWidth = /**
         * Sets the drawer width.
         * @param width Width to set, must be valid CSS size string.
         */
    function (width) {
        var _this = this;
        window.requestAnimationFrame(function () {
            if (_this.drawer) {
                _this.renderer.setElementStyle(_this.drawer, "width", width);
            }
        });
    };
    /**
     * Get current Drawer width.
     */
    /**
         * Get current Drawer width.
         */
    NavigationDrawer.prototype.getDrawerWidth = /**
         * Get current Drawer width.
         */
    function () {
        return this.drawer.offsetWidth;
    };
    NavigationDrawer.prototype.ensureEvents = function () {
        var _this = this;
        // set listeners for swipe/pan only if needed, but just once
        if (this.enableGestures && !this.pin && !this._gesturesAttached) {
            // Built-in manager handler(L20887) causes endless loop and max stack exception.
            // https://github.com/angular/angular/issues/6993
            // Use ours for now (until beta.10):
            // this.renderer.listen(document, "swipe", this.swipe);
            this._touchManager.addGlobalEventListener("document", "swipe", this.swipe);
            this._gesturesAttached = true;
            // this.renderer.listen(document, "panstart", this.panstart);
            // this.renderer.listen(document, "pan", this.pan);
            this._touchManager.addGlobalEventListener("document", "panstart", this.panstart);
            this._touchManager.addGlobalEventListener("document", "panmove", this.pan);
            this._touchManager.addGlobalEventListener("document", "panend", this.panEnd);
        }
        if (this.pinThreshold && !this._resizeObserver) {
            this._resizeObserver = Observable.fromEvent(window, "resize").debounce(function () { return Observable.interval(150); })
                .subscribe(function (value) { _this.checkPinThreshold(); });
        }
    };
    NavigationDrawer.prototype.updateEdgeZone = function () {
        var maxValue;
        if (this._hasMimiTempl) {
            maxValue = Math.max(this._maxEdgeZone, this.getExpectedWidth(true) * 1.1);
            this.set_maxEdgeZone(maxValue);
        }
    };
    NavigationDrawer.prototype.resetPan = function () {
        this._panning = false;
        /* styles fail to apply when set on parent due to extra attributes, prob ng bug */
        this.renderer.setElementClass(this.overlay, "panning", false);
        this.renderer.setElementClass(this.drawer, "panning", false);
        this.setXSize(0, "");
    };
    /**
     * Sets the absolute position or width in case the drawer doesn't change position.
     * @param x the number pixels to translate on the X axis or the width to set. 0 width will clear the style instead.
     * @param opacity optional value to apply to the overlay
     */
    /**
         * Sets the absolute position or width in case the drawer doesn't change position.
         * @param x the number pixels to translate on the X axis or the width to set. 0 width will clear the style instead.
         * @param opacity optional value to apply to the overlay
         */
    NavigationDrawer.prototype.setXSize = /**
         * Sets the absolute position or width in case the drawer doesn't change position.
         * @param x the number pixels to translate on the X axis or the width to set. 0 width will clear the style instead.
         * @param opacity optional value to apply to the overlay
         */
    function (x, opacity) {
        var _this = this;
        // Angular polyfills patches window.requestAnimationFrame, but switch to DomAdapter API (TODO)
        window.requestAnimationFrame(function () {
            if (_this.hasAnimateWidth) {
                _this.renderer.setElementStyle(_this.drawer, "width", x ? Math.abs(x) + "px" : "");
            }
            else {
                _this.renderer.setElementStyle(_this.drawer, "transform", x ? "translate3d(" + x + "px,0,0)" : "");
                _this.renderer.setElementStyle(_this.drawer, "-webkit-transform", x ? "translate3d(" + x + "px,0,0)" : "");
            }
            if (opacity !== undefined) {
                _this.renderer.setElementStyle(_this.overlay, "opacity", opacity);
            }
        });
    };
    NavigationDrawer.decorators = [
        { type: Component, args: [{
                    providers: [HammerGesturesManager],
                    selector: "igx-nav-drawer",
                    styles: ["\n      .ig-nav-drawer{position:fixed;width:15.125em;height:100%;max-width:90%;min-height:100%;overflow-x:hidden;background-color:#fff;top:0;bottom:0;left:0;z-index:999;-webkit-transition-property:width, -webkit-transform;transition-property:width, -webkit-transform;transition-property:width, transform;transition-property:width, transform, -webkit-transform;-webkit-transition-duration:.3s, .3s;transition-duration:.3s, .3s;-webkit-transition-timing-function:cubic-bezier(0.25, 0.46, 0.45, 0.94),cubic-bezier(0.25, 0.46, 0.45, 0.94);transition-timing-function:cubic-bezier(0.25, 0.46, 0.45, 0.94),cubic-bezier(0.25, 0.46, 0.45, 0.94);-webkit-transition-delay:0s, 0s;transition-delay:0s, 0s;-webkit-box-shadow:0 8px 10px -5px rgba(0,0,0,0.26),0 16px 24px 2px rgba(0,0,0,0.12),0 6px 30px 5px rgba(0,0,0,0.08);box-shadow:0 8px 10px -5px rgba(0,0,0,0.26),0 16px 24px 2px rgba(0,0,0,0.12),0 6px 30px 5px rgba(0,0,0,0.08)}.ig-nav-drawer.collapsed{-webkit-transform:translate3d(-300px, 0, 0);transform:translate3d(-300px, 0, 0);-webkit-box-shadow:none;box-shadow:none}.ig-nav-drawer.collapsed.right{-webkit-transform:translate3d(300px, 0, 0);transform:translate3d(300px, 0, 0);-webkit-box-shadow:none;box-shadow:none}.ig-nav-drawer.right{left:auto;right:0}.ig-nav-drawer.mini{width:60px;-webkit-transition-duration:.2s, .2s;transition-duration:.2s, .2s}.ig-nav-drawer.pinned{position:relative;max-width:100%;-webkit-box-shadow:none;box-shadow:none;z-index:0}.ig-nav-drawer.pinned.collapsed{-webkit-transform:none;transform:none;width:0;padding:0;overflow:hidden}.ig-nav-drawer.panning{overflow-x:hidden;-webkit-transition:none;transition:none}.style-dummy{height:0;background:none;-webkit-box-shadow:none;box-shadow:none;-webkit-transition:none;transition:none;visibility:hidden}.ig-nav-drawer-overlay{opacity:1;background-color:rgba(0,0,0,0.38);-webkit-transition-property:opacity, visibility;transition-property:opacity, visibility;-webkit-transition-duration:.25s, .25s;transition-duration:.25s, .25s;-webkit-transition-timing-function:ease-in, step-start;transition-timing-function:ease-in, step-start;-webkit-transition-delay:0s, 0s;transition-delay:0s, 0s;position:absolute;left:0;top:0;width:100%;height:100%;visibility:visible;z-index:999}.ig-nav-drawer-overlay.hidden{-webkit-transition-timing-function:ease-in-out, step-end;transition-timing-function:ease-in-out, step-end;visibility:hidden;opacity:0}.ig-nav-drawer-overlay.pinned{display:none}.ig-nav-drawer-overlay.panning{-webkit-transform:translate3d(0, 0, 0);transform:translate3d(0, 0, 0);-webkit-transition:none;transition:none}.ig-nav-drawer-overlay.panning.hidden{visibility:visible}\n    "],
                    template: "\n      <div class=\"ig-nav-drawer-overlay\" [class.pinned]=\"pin\" [class.hidden]=\"!isOpen\" (click)=\"close(true)\"></div>\n      <aside class=\"ig-nav-drawer\" role=\"navigation\" \n          [class.collapsed]=\"!_hasMimiTempl && !isOpen\" [class.mini]=\"_hasMimiTempl && !isOpen\" [class.pinned]=\"pin\" [class.right]=\"position == 'right'\">\n    \n          <div class=\"\" [hidden]=\"!isOpen && _hasMimiTempl\">\n              <ng-content select=\".ig-drawer-content\"></ng-content>\n          </div>                \n          <div class=\"\" [hidden]=\"isOpen\">\n              <ng-content select=\".ig-drawer-mini-content\"></ng-content>\n          </div>\n      </aside>\n      <div class=\"style-dummy\"></div>\n    "
                },] },
    ];
    /** @nocollapse */
    NavigationDrawer.ctorParameters = function () { return [
        { type: ElementRef, decorators: [{ type: Inject, args: [ElementRef,] },] },
        { type: NavigationService, decorators: [{ type: Optional },] },
        { type: Renderer, },
        { type: HammerGesturesManager, },
    ]; };
    NavigationDrawer.propDecorators = {
        "id": [{ type: Input },],
        "position": [{ type: Input },],
        "enableGestures": [{ type: Input },],
        "isOpen": [{ type: Input },],
        "pin": [{ type: Input },],
        "pinThreshold": [{ type: Input },],
        "width": [{ type: Input },],
        "miniWidth": [{ type: Input },],
        "pinChange": [{ type: Output },],
        "opening": [{ type: Output },],
        "opened": [{ type: Output },],
        "closing": [{ type: Output },],
        "closed": [{ type: Output },],
    };
    return NavigationDrawer;
}(BaseComponent));
export { NavigationDrawer };
var NavigationDrawerModule = (function () {
    function NavigationDrawerModule() {
    }
    NavigationDrawerModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [NavigationDrawer],
                    exports: [NavigationDrawer]
                },] },
    ];
    /** @nocollapse */
    NavigationDrawerModule.ctorParameters = function () { return []; };
    return NavigationDrawerModule;
}());
export { NavigationDrawerModule };
//# sourceMappingURL=navigation-drawer.component.js.map