var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
import { CommonModule } from "@angular/common";
import { Component, ElementRef, EventEmitter, Input, NgModule, Output, ViewChild } from "@angular/core";
import { HAMMER_GESTURE_CONFIG, HammerGestureConfig } from "@angular/platform-browser";
var ScrollHammerGestureManager = (function (_super) {
    __extends(ScrollHammerGestureManager, _super);
    function ScrollHammerGestureManager() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.overrides = {
            pan: { threshold: 0, direction: Hammer.DIRECTION_VERTICAL }
        };
        return _this;
    }
    return ScrollHammerGestureManager;
}(HammerGestureConfig));
export { ScrollHammerGestureManager };
var IgxScroll = (function () {
    function IgxScroll() {
        /**
             * Scroll event executed each time when the viewport of the IgxScroll is scrolled.
             * @type {EventEmitter<IgxScrollEvent>}
             */
        this.onScroll = new EventEmitter();
    }
    Object.defineProperty(IgxScroll.prototype, "scrollTop", {
        /**
         * Gets the scroll top of the scroll
         * @returns {number}
         */
        get: /**
             * Gets the scroll top of the scroll
             * @returns {number}
             */
        function () {
            return this.verticalScroll.nativeElement.scrollTop;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Scroll with the given delta. Does not scrolls when the scroll delta is outside of the scroll boundaries
     * @param delta
     */
    /**
         * Scroll with the given delta. Does not scrolls when the scroll delta is outside of the scroll boundaries
         * @param delta
         */
    IgxScroll.prototype.scrollVertically = /**
         * Scroll with the given delta. Does not scrolls when the scroll delta is outside of the scroll boundaries
         * @param delta
         */
    function (delta) {
        this.verticalScroll.nativeElement.scrollTop += delta;
        if (this.verticalScroll.nativeElement.scrollTop < 0) {
            return;
        }
        this.emitScroll();
    };
    Object.defineProperty(IgxScroll.prototype, "totalHeight", {
        get: function () {
            return this.itemHeight * this.visibleItemsCount + "px";
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgxScroll.prototype, "innerHeight", {
        get: function () {
            return this.totalItemsCount * this.itemHeight + "px";
        },
        enumerable: true,
        configurable: true
    });
    IgxScroll.prototype.onMouseWheel = function ($event) {
        this.scrollVertically($event.deltaY);
        $event.preventDefault();
    };
    IgxScroll.prototype.onPan = function ($event) {
        var _this = this;
        if ($event.pointerType !== "touch") {
            return;
        }
        this.amplitude = 0.8 * $event.velocityY;
        this.timestamp = $event.timeStamp;
        this.target = Math.round($event.deltaY + this.amplitude);
        this.animationFrameId = requestAnimationFrame(function (timestamp) { return _this.run(timestamp); });
    };
    IgxScroll.prototype.onScrolled = function ($event) {
        this.emitScroll();
    };
    IgxScroll.prototype.run = function (timeStamp) {
        var _this = this;
        var elapsed;
        var delta;
        elapsed = Date.now() - this.timestamp;
        delta = this.amplitude * Math.exp(-elapsed / 325);
        if (delta > 0.5 || delta < -0.5) {
            this.scrollVertically((this.target + delta) * -1);
            requestAnimationFrame(function (timestamp) { return _this.run(timestamp); });
        }
        else {
            this.scrollVertically(this.target * -1);
        }
    };
    IgxScroll.prototype.emitScroll = function () {
        var currentTop = this.verticalScroll.nativeElement.scrollTop / this.itemHeight;
        if (this.verticalScroll.nativeElement.scrollTop % this.itemHeight !== 0) {
            currentTop = Math.round(currentTop);
        }
        this.onScroll.emit({ currentTop: currentTop });
    };
    IgxScroll.decorators = [
        { type: Component, args: [{
                    selector: "igx-scroll",
                    styles: ["\n      .igx-scroll__viewport{display:inline-block;overflow-y:hidden}.igx-scroll__vertical{display:inline-block;width:20px;overflow-y:auto}\n    "],
                    template: "\n      <div class=\"igx-scroll\"\n           #scroll>\n          <div class=\"igx-scroll__viewport\" [ngStyle]=\"{ 'height': totalHeight }\"\n               (pan)=\"onPan($event)\"\n               (wheel)=\"onMouseWheel($event)\">\n              <ng-content>\n              </ng-content>\n          </div>\n          <div (scroll)=\"onScrolled($event)\"\n               #verticalScroll class=\"igx-scroll__vertical\" [ngStyle]=\"{ 'height': totalHeight }\">\n              <div [ngStyle]=\"{ 'height': innerHeight }\">\n              </div>\n          </div>\n      </div>\n    "
                },] },
    ];
    /** @nocollapse */
    IgxScroll.ctorParameters = function () { return []; };
    IgxScroll.propDecorators = {
        "visibleItemsCount": [{ type: Input },],
        "totalItemsCount": [{ type: Input },],
        "itemHeight": [{ type: Input },],
        "onScroll": [{ type: Output },],
        "verticalScroll": [{ type: ViewChild, args: ["verticalScroll",] },],
    };
    return IgxScroll;
}());
export { IgxScroll };
var IgxScrollModule = (function () {
    function IgxScrollModule() {
    }
    IgxScrollModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [IgxScroll],
                    exports: [IgxScroll],
                    imports: [CommonModule],
                    providers: [{
                            provide: HAMMER_GESTURE_CONFIG,
                            useClass: ScrollHammerGestureManager
                        }]
                },] },
    ];
    /** @nocollapse */
    IgxScrollModule.ctorParameters = function () { return []; };
    return IgxScrollModule;
}());
export { IgxScrollModule };
//# sourceMappingURL=scroll.component.js.map